import typing

import android.os
import android.ranging
import android.ranging.ble.cs
import android.ranging.ble.rssi
import android.ranging.uwb
import android.ranging.wifi.rtt
import java
import java.lang
import java.util

class RawInitiatorRangingConfig(android.os.Parcelable, android.ranging.RangingConfig):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RawInitiatorRangingConfig]] = ...
    def describeContents(self) -> int: ...
    def getRawRangingDevices(self) -> java.util.List[RawRangingDevice]: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addRawRangingDevice(self, rangingDevice: RawRangingDevice, /) -> RawInitiatorRangingConfig.Builder: ...
        def addRawRangingDevices(self, rangingDevices: java.util.List[RawRangingDevice], /) -> RawInitiatorRangingConfig.Builder: ...
        def build(self) -> RawInitiatorRangingConfig: ...

class RawRangingDevice(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RawRangingDevice]] = ...
    UPDATE_RATE_FREQUENT: typing.ClassVar[int] = ...
    UPDATE_RATE_INFREQUENT: typing.ClassVar[int] = ...
    UPDATE_RATE_NORMAL: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getBleRssiRangingParams(self) -> android.ranging.ble.rssi.BleRssiRangingParams: ...
    def getCsRangingParams(self) -> android.ranging.ble.cs.BleCsRangingParams: ...
    def getRangingDevice(self) -> android.ranging.RangingDevice: ...
    def getRttRangingParams(self) -> android.ranging.wifi.rtt.RttRangingParams: ...
    def getUwbRangingParams(self) -> android.ranging.uwb.UwbRangingParams: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> RawRangingDevice: ...
        def setBleRssiRangingParams(self, params: android.ranging.ble.rssi.BleRssiRangingParams, /) -> RawRangingDevice.Builder: ...
        def setCsRangingParams(self, params: android.ranging.ble.cs.BleCsRangingParams, /) -> RawRangingDevice.Builder: ...
        def setRangingDevice(self, rangingDevice: android.ranging.RangingDevice, /) -> RawRangingDevice.Builder: ...
        def setRttRangingParams(self, params: android.ranging.wifi.rtt.RttRangingParams, /) -> RawRangingDevice.Builder: ...
        def setUwbRangingParams(self, params: android.ranging.uwb.UwbRangingParams, /) -> RawRangingDevice.Builder: ...

class RawResponderRangingConfig(android.os.Parcelable, android.ranging.RangingConfig):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RawResponderRangingConfig]] = ...
    def describeContents(self) -> int: ...
    def getRawRangingDevice(self) -> RawRangingDevice: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> RawResponderRangingConfig: ...
        def setRawRangingDevice(self, rangingDevice: RawRangingDevice, /) -> RawResponderRangingConfig.Builder: ...



import typing

import android.app
import android.app.assist
import android.content
import android.content.res
import android.graphics
import android.os
import android.view
import java
import java.chaquopy
import java.io
import java.lang
import java.util
import java.util.concurrent
import java.util.function

class VisibleActivityInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VisibleActivityInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getActivityId(self) -> VoiceInteractionSession.ActivityId: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class VoiceInteractionService(android.app.Service):
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    SERVICE_META_DATA: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def dump(self, fd: java.io.FileDescriptor, pw: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def getDisabledShowContext(self) -> int: ...
    @staticmethod
    def isActiveService(context: android.content.Context, service: android.content.ComponentName, /) -> bool: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onGetSupportedVoiceActions(self, voiceActions: java.util.Set[java.lang.String], /) -> java.util.Set[java.lang.String]: ...
    def onLaunchVoiceAssistFromKeyguard(self) -> None: ...
    def onPrepareToShowSession(self, args: android.os.Bundle, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def onReady(self) -> None: ...
    def onShowSessionFailed(self, args: android.os.Bundle, /) -> None: ...
    def onShutdown(self) -> None: ...
    def setDisabledShowContext(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def setUiHints(self, hints: android.os.Bundle, /) -> None: ...
    def showSession(self, args: android.os.Bundle, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class VoiceInteractionSession(android.content.ComponentCallbacks2, android.view.KeyEvent.Callback):
    KEY_FOREGROUND_ACTIVITIES: typing.ClassVar[str] = ...
    KEY_SHOW_SESSION_ID: typing.ClassVar[str] = ...
    SHOW_SOURCE_ACTIVITY: typing.ClassVar[int] = ...
    SHOW_SOURCE_APPLICATION: typing.ClassVar[int] = ...
    SHOW_SOURCE_ASSIST_GESTURE: typing.ClassVar[int] = ...
    SHOW_SOURCE_AUTOMOTIVE_SYSTEM_UI: typing.ClassVar[int] = ...
    SHOW_SOURCE_NOTIFICATION: typing.ClassVar[int] = ...
    SHOW_SOURCE_PUSH_TO_TALK: typing.ClassVar[int] = ...
    SHOW_WITH_ASSIST: typing.ClassVar[int] = ...
    SHOW_WITH_SCREENSHOT: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, handler: android.os.Handler, /) -> None: ...
    def closeSystemDialogs(self) -> None: ...
    def dump(self, prefix: str | java.lang.String, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def finish(self) -> None: ...
    def getContext(self) -> android.content.Context: ...
    def getDisabledShowContext(self) -> int: ...
    def getLayoutInflater(self) -> android.view.LayoutInflater: ...
    def getUserDisabledShowContext(self) -> int: ...
    def getWindow(self) -> android.app.Dialog: ...
    def hide(self) -> None: ...
    def onAssistStructureFailure(self, failure: java.lang.Throwable, /) -> None: ...
    def onBackPressed(self) -> None: ...
    def onCancelRequest(self, request: VoiceInteractionSession.Request, /) -> None: ...
    def onCloseSystemDialogs(self) -> None: ...
    def onComputeInsets(self, outInsets: VoiceInteractionSession.Insets, /) -> None: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onCreate(self) -> None: ...
    def onCreateContentView(self) -> android.view.View: ...
    def onDestroy(self) -> None: ...
    def onDirectActionsInvalidated(self, activityId: VoiceInteractionSession.ActivityId, /) -> None: ...
    def onGetSupportedCommands(self, commands: java.chaquopy.JavaArray[java.lang.String], /) -> java.chaquopy.JavaArrayJBoolean: ...
    @typing.overload
    def onHandleAssist(self, state: VoiceInteractionSession.AssistState, /) -> None: ...
    @typing.overload
    def onHandleAssist(self, data: android.os.Bundle, structure: android.app.assist.AssistStructure, content: android.app.assist.AssistContent, /) -> None: ...
    def onHandleAssistSecondary(self, data: android.os.Bundle, structure: android.app.assist.AssistStructure, content: android.app.assist.AssistContent, index: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def onHandleScreenshot(self, screenshot: android.graphics.Bitmap, /) -> None: ...
    def onHide(self) -> None: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyLongPress(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyMultiple(self, keyCode: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onLockscreenShown(self) -> None: ...
    def onLowMemory(self) -> None: ...
    def onPrepareShow(self, args: android.os.Bundle, showFlags: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRequestAbortVoice(self, request: VoiceInteractionSession.AbortVoiceRequest, /) -> None: ...
    def onRequestCommand(self, request: VoiceInteractionSession.CommandRequest, /) -> None: ...
    def onRequestCompleteVoice(self, request: VoiceInteractionSession.CompleteVoiceRequest, /) -> None: ...
    def onRequestConfirmation(self, request: VoiceInteractionSession.ConfirmationRequest, /) -> None: ...
    def onRequestPickOption(self, request: VoiceInteractionSession.PickOptionRequest, /) -> None: ...
    def onShow(self, args: android.os.Bundle, showFlags: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTaskFinished(self, intent: android.content.Intent, taskId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTaskStarted(self, intent: android.content.Intent, taskId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTrimMemory(self, level: int | java.jint | java.lang.Integer, /) -> None: ...
    def performDirectAction(self, action: android.app.DirectAction, extras: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, resultExecutor: java.util.concurrent.Executor, resultListener: java.util.function.Consumer[android.os.Bundle], /) -> None: ...
    def registerVisibleActivityCallback(self, executor: java.util.concurrent.Executor, callback: VoiceInteractionSession.VisibleActivityCallback, /) -> None: ...
    def requestDirectActions(self, activityId: VoiceInteractionSession.ActivityId, cancellationSignal: android.os.CancellationSignal, resultExecutor: java.util.concurrent.Executor, callback: java.util.function.Consumer[java.util.List[android.app.DirectAction]], /) -> None: ...
    def setContentView(self, view: android.view.View, /) -> None: ...
    def setDisabledShowContext(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def setKeepAwake(self, keepAwake: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTheme(self, theme: int | java.jint | java.lang.Integer, /) -> None: ...
    def setUiEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def show(self, args: android.os.Bundle, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startAssistantActivity(self, intent: android.content.Intent, /) -> None: ...
    @typing.overload
    def startAssistantActivity(self, intent: android.content.Intent, bundle: android.os.Bundle, /) -> None: ...
    def startVoiceActivity(self, intent: android.content.Intent, /) -> None: ...
    def unregisterVisibleActivityCallback(self, callback: VoiceInteractionSession.VisibleActivityCallback, /) -> None: ...

    class VisibleActivityCallback(java.lang.Object):
        def onInvisible(self, activityId: VoiceInteractionSession.ActivityId, /) -> None: ...
        def onVisible(self, activityInfo: VisibleActivityInfo, /) -> None: ...

    class Request(java.lang.Object):
        def cancel(self) -> None: ...
        def getCallingPackage(self) -> str: ...
        def getCallingUid(self) -> int: ...
        def getExtras(self) -> android.os.Bundle: ...
        def isActive(self) -> bool: ...
        def toString(self) -> str: ...

    class PickOptionRequest(VoiceInteractionSession.Request):
        def getOptions(self) -> java.chaquopy.JavaArray[android.app.VoiceInteractor.PickOptionRequest.Option]: ...
        def getPrompt(self) -> java.lang.CharSequence: ...
        def getVoicePrompt(self) -> android.app.VoiceInteractor.Prompt: ...
        def sendIntermediatePickOptionResult(self, selections: java.chaquopy.JavaArray[android.app.VoiceInteractor.PickOptionRequest.Option], result: android.os.Bundle, /) -> None: ...
        def sendPickOptionResult(self, selections: java.chaquopy.JavaArray[android.app.VoiceInteractor.PickOptionRequest.Option], result: android.os.Bundle, /) -> None: ...

    class Insets(java.lang.Object):
        TOUCHABLE_INSETS_CONTENT: typing.ClassVar[int] = ...
        TOUCHABLE_INSETS_FRAME: typing.ClassVar[int] = ...
        TOUCHABLE_INSETS_REGION: typing.ClassVar[int] = ...
        contentInsets: android.graphics.Rect = ...
        touchableInsets: int = ...
        touchableRegion: android.graphics.Region = ...
        def __init__(self) -> None: ...

    class ConfirmationRequest(VoiceInteractionSession.Request):
        def getPrompt(self) -> java.lang.CharSequence: ...
        def getVoicePrompt(self) -> android.app.VoiceInteractor.Prompt: ...
        def sendConfirmationResult(self, confirmed: bool | java.jboolean | java.lang.Boolean, result: android.os.Bundle, /) -> None: ...

    class CompleteVoiceRequest(VoiceInteractionSession.Request):
        def getMessage(self) -> java.lang.CharSequence: ...
        def getVoicePrompt(self) -> android.app.VoiceInteractor.Prompt: ...
        def sendCompleteResult(self, result: android.os.Bundle, /) -> None: ...

    class CommandRequest(VoiceInteractionSession.Request):
        def getCommand(self) -> str: ...
        def sendIntermediateResult(self, result: android.os.Bundle, /) -> None: ...
        def sendResult(self, result: android.os.Bundle, /) -> None: ...

    class AssistState(java.lang.Object):
        def getActivityId(self) -> VoiceInteractionSession.ActivityId: ...
        def getAssistContent(self) -> android.app.assist.AssistContent: ...
        def getAssistData(self) -> android.os.Bundle: ...
        def getAssistStructure(self) -> android.app.assist.AssistStructure: ...
        def getCount(self) -> int: ...
        def getIndex(self) -> int: ...
        def isFocused(self) -> bool: ...

    class ActivityId(java.lang.Object):
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def hashCode(self) -> int: ...

    class AbortVoiceRequest(VoiceInteractionSession.Request):
        def getMessage(self) -> java.lang.CharSequence: ...
        def getVoicePrompt(self) -> android.app.VoiceInteractor.Prompt: ...
        def sendAbortResult(self, result: android.os.Bundle, /) -> None: ...

class VoiceInteractionSessionService(android.app.Service):
    def __init__(self) -> None: ...
    def dump(self, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onCreate(self) -> None: ...
    def onLowMemory(self) -> None: ...
    def onNewSession(self, arg1: android.os.Bundle, /) -> VoiceInteractionSession: ...
    def onTrimMemory(self, level: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.app
import android.content
import android.os
import android.view.textservice
import java
import java.chaquopy
import java.lang

class SpellCheckerService(android.app.Service):
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def createSession(self) -> SpellCheckerService.Session: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...

    class Session(java.lang.Object):
        def __init__(self) -> None: ...
        def getBundle(self) -> android.os.Bundle: ...
        def getLocale(self) -> str: ...
        def getSupportedAttributes(self) -> int: ...
        def onCancel(self) -> None: ...
        def onClose(self) -> None: ...
        def onCreate(self) -> None: ...
        def onGetSentenceSuggestionsMultiple(self, textInfos: java.chaquopy.JavaArray[android.view.textservice.TextInfo], suggestionsLimit: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[android.view.textservice.SentenceSuggestionsInfo]: ...
        def onGetSuggestions(self, arg1: android.view.textservice.TextInfo, arg2: int | java.jint | java.lang.Integer, /) -> android.view.textservice.SuggestionsInfo: ...
        def onGetSuggestionsMultiple(self, textInfos: java.chaquopy.JavaArray[android.view.textservice.TextInfo], suggestionsLimit: int | java.jint | java.lang.Integer, sequentialWords: bool | java.jboolean | java.lang.Boolean, /) -> java.chaquopy.JavaArray[android.view.textservice.SuggestionsInfo]: ...



import typing

import java.lang

class XMLConstants(java.lang.Object):
    DEFAULT_NS_PREFIX: typing.ClassVar[str] = ...
    FEATURE_SECURE_PROCESSING: typing.ClassVar[str] = ...
    NULL_NS_URI: typing.ClassVar[str] = ...
    RELAXNG_NS_URI: typing.ClassVar[str] = ...
    W3C_XML_SCHEMA_INSTANCE_NS_URI: typing.ClassVar[str] = ...
    W3C_XML_SCHEMA_NS_URI: typing.ClassVar[str] = ...
    W3C_XPATH_DATATYPE_NS_URI: typing.ClassVar[str] = ...
    XMLNS_ATTRIBUTE: typing.ClassVar[str] = ...
    XMLNS_ATTRIBUTE_NS_URI: typing.ClassVar[str] = ...
    XML_DTD_NS_URI: typing.ClassVar[str] = ...
    XML_NS_PREFIX: typing.ClassVar[str] = ...
    XML_NS_URI: typing.ClassVar[str] = ...



import typing

import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent
import java.util.function

_BaseStream__T = typing.TypeVar('_BaseStream__T')  # <T>
_BaseStream__S = typing.TypeVar('_BaseStream__S')  # <S>
class BaseStream(java.lang.AutoCloseable, typing.Generic[_BaseStream__T, _BaseStream__S]):
    def close(self) -> None: ...
    def isParallel(self) -> bool: ...
    def iterator(self) -> java.util.Iterator[_BaseStream__T]: ...
    def onClose(self, arg1: java.lang.Runnable, /) -> _BaseStream__S: ...
    def parallel(self) -> _BaseStream__S: ...
    def sequential(self) -> _BaseStream__S: ...
    def spliterator(self) -> java.util.Spliterator[_BaseStream__T]: ...
    def unordered(self) -> _BaseStream__S: ...

_Collector__T = typing.TypeVar('_Collector__T')  # <T>
_Collector__A = typing.TypeVar('_Collector__A')  # <A>
_Collector__R = typing.TypeVar('_Collector__R')  # <R>
class Collector(java.lang.Object, typing.Generic[_Collector__T, _Collector__A, _Collector__R]):
    def accumulator(self) -> java.util.function.BiConsumer[_Collector__A, _Collector__T]: ...
    def characteristics(self) -> java.util.Set[Collector.Characteristics]: ...
    def combiner(self) -> java.util.function.BinaryOperator[_Collector__A]: ...
    def finisher(self) -> java.util.function.Function[_Collector__A, _Collector__R]: ...
    _of_0__T = typing.TypeVar('_of_0__T')  # <T>
    _of_0__R = typing.TypeVar('_of_0__R')  # <R>
    _of_1__T = typing.TypeVar('_of_1__T')  # <T>
    _of_1__A = typing.TypeVar('_of_1__A')  # <A>
    _of_1__R = typing.TypeVar('_of_1__R')  # <R>
    @typing.overload
    @staticmethod
    def of(supplier: java.util.function.Supplier[_of_0__R], accumulator: java.util.function.BiConsumer[_of_0__R, _of_0__T], combiner: java.util.function.BinaryOperator[_of_0__R], /, *characteristics: Collector.Characteristics) -> Collector[_of_0__T, _of_0__R, _of_0__R]: ...
    @typing.overload
    @staticmethod
    def of(supplier: java.util.function.Supplier[_of_1__A], accumulator: java.util.function.BiConsumer[_of_1__A, _of_1__T], combiner: java.util.function.BinaryOperator[_of_1__A], finisher: java.util.function.Function[_of_1__A, _of_1__R], /, *characteristics: Collector.Characteristics) -> Collector[_of_1__T, _of_1__A, _of_1__R]: ...
    def supplier(self) -> java.util.function.Supplier[_Collector__A]: ...

    class Characteristics(java.lang.Enum[Collector.Characteristics]):
        CONCURRENT: typing.ClassVar[Collector.Characteristics] = ...
        IDENTITY_FINISH: typing.ClassVar[Collector.Characteristics] = ...
        UNORDERED: typing.ClassVar[Collector.Characteristics] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> Collector.Characteristics: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[Collector.Characteristics]: ...

class Collectors(java.lang.Object):
    _averagingDouble__T = typing.TypeVar('_averagingDouble__T')  # <T>
    @staticmethod
    def averagingDouble(mapper: java.util.function.ToDoubleFunction[_averagingDouble__T], /) -> Collector[_averagingDouble__T, java.lang.Object, java.lang.Double]: ...
    _averagingInt__T = typing.TypeVar('_averagingInt__T')  # <T>
    @staticmethod
    def averagingInt(mapper: java.util.function.ToIntFunction[_averagingInt__T], /) -> Collector[_averagingInt__T, java.lang.Object, java.lang.Double]: ...
    _averagingLong__T = typing.TypeVar('_averagingLong__T')  # <T>
    @staticmethod
    def averagingLong(mapper: java.util.function.ToLongFunction[_averagingLong__T], /) -> Collector[_averagingLong__T, java.lang.Object, java.lang.Double]: ...
    _collectingAndThen__T = typing.TypeVar('_collectingAndThen__T')  # <T>
    _collectingAndThen__A = typing.TypeVar('_collectingAndThen__A')  # <A>
    _collectingAndThen__R = typing.TypeVar('_collectingAndThen__R')  # <R>
    _collectingAndThen__RR = typing.TypeVar('_collectingAndThen__RR')  # <RR>
    @staticmethod
    def collectingAndThen(downstream: Collector[_collectingAndThen__T, _collectingAndThen__A, _collectingAndThen__R], finisher: java.util.function.Function[_collectingAndThen__R, _collectingAndThen__RR], /) -> Collector[_collectingAndThen__T, _collectingAndThen__A, _collectingAndThen__RR]: ...
    @staticmethod
    def counting() -> Collector[java.lang.Object, java.lang.Object, java.lang.Long]: ...
    _filtering__T = typing.TypeVar('_filtering__T')  # <T>
    _filtering__R = typing.TypeVar('_filtering__R')  # <R>
    @staticmethod
    def filtering(predicate: java.util.function.Predicate[_filtering__T], downstream: Collector[_filtering__T, java.lang.Object, _filtering__R], /) -> Collector[_filtering__T, java.lang.Object, _filtering__R]: ...
    _flatMapping__T = typing.TypeVar('_flatMapping__T')  # <T>
    _flatMapping__U = typing.TypeVar('_flatMapping__U')  # <U>
    _flatMapping__R = typing.TypeVar('_flatMapping__R')  # <R>
    @staticmethod
    def flatMapping(mapper: java.util.function.Function[_flatMapping__T, Stream[_flatMapping__U]], downstream: Collector[_flatMapping__U, java.lang.Object, _flatMapping__R], /) -> Collector[_flatMapping__T, java.lang.Object, _flatMapping__R]: ...
    _groupingBy_0__T = typing.TypeVar('_groupingBy_0__T')  # <T>
    _groupingBy_0__K = typing.TypeVar('_groupingBy_0__K')  # <K>
    _groupingBy_1__T = typing.TypeVar('_groupingBy_1__T')  # <T>
    _groupingBy_1__K = typing.TypeVar('_groupingBy_1__K')  # <K>
    _groupingBy_1__D = typing.TypeVar('_groupingBy_1__D')  # <D>
    _groupingBy_2__T = typing.TypeVar('_groupingBy_2__T')  # <T>
    _groupingBy_2__M = typing.TypeVar('_groupingBy_2__M')  # <M>
    @typing.overload
    @staticmethod
    def groupingBy(classifier: java.util.function.Function[_groupingBy_0__T, _groupingBy_0__K], /) -> Collector[_groupingBy_0__T, java.lang.Object, java.util.Map[_groupingBy_0__K, java.util.List[_groupingBy_0__T]]]: ...
    @typing.overload
    @staticmethod
    def groupingBy(classifier: java.util.function.Function[_groupingBy_1__T, _groupingBy_1__K], downstream: Collector[_groupingBy_1__T, java.lang.Object, _groupingBy_1__D], /) -> Collector[_groupingBy_1__T, java.lang.Object, java.util.Map[_groupingBy_1__K, _groupingBy_1__D]]: ...
    @typing.overload
    @staticmethod
    def groupingBy(classifier: java.util.function.Function[_groupingBy_2__T, java.lang.Object], mapFactory: java.util.function.Supplier[_groupingBy_2__M], downstream: Collector[_groupingBy_2__T, java.lang.Object, java.lang.Object], /) -> Collector[_groupingBy_2__T, java.lang.Object, _groupingBy_2__M]: ...
    _groupingByConcurrent_0__T = typing.TypeVar('_groupingByConcurrent_0__T')  # <T>
    _groupingByConcurrent_0__K = typing.TypeVar('_groupingByConcurrent_0__K')  # <K>
    _groupingByConcurrent_1__T = typing.TypeVar('_groupingByConcurrent_1__T')  # <T>
    _groupingByConcurrent_1__K = typing.TypeVar('_groupingByConcurrent_1__K')  # <K>
    _groupingByConcurrent_1__D = typing.TypeVar('_groupingByConcurrent_1__D')  # <D>
    _groupingByConcurrent_2__T = typing.TypeVar('_groupingByConcurrent_2__T')  # <T>
    _groupingByConcurrent_2__M = typing.TypeVar('_groupingByConcurrent_2__M')  # <M>
    @typing.overload
    @staticmethod
    def groupingByConcurrent(classifier: java.util.function.Function[_groupingByConcurrent_0__T, _groupingByConcurrent_0__K], /) -> Collector[_groupingByConcurrent_0__T, java.lang.Object, java.util.concurrent.ConcurrentMap[_groupingByConcurrent_0__K, java.util.List[_groupingByConcurrent_0__T]]]: ...
    @typing.overload
    @staticmethod
    def groupingByConcurrent(classifier: java.util.function.Function[_groupingByConcurrent_1__T, _groupingByConcurrent_1__K], downstream: Collector[_groupingByConcurrent_1__T, java.lang.Object, _groupingByConcurrent_1__D], /) -> Collector[_groupingByConcurrent_1__T, java.lang.Object, java.util.concurrent.ConcurrentMap[_groupingByConcurrent_1__K, _groupingByConcurrent_1__D]]: ...
    @typing.overload
    @staticmethod
    def groupingByConcurrent(classifier: java.util.function.Function[_groupingByConcurrent_2__T, java.lang.Object], mapFactory: java.util.function.Supplier[_groupingByConcurrent_2__M], downstream: Collector[_groupingByConcurrent_2__T, java.lang.Object, java.lang.Object], /) -> Collector[_groupingByConcurrent_2__T, java.lang.Object, _groupingByConcurrent_2__M]: ...
    @typing.overload
    @staticmethod
    def joining() -> Collector[java.lang.CharSequence, java.lang.Object, java.lang.String]: ...
    @typing.overload
    @staticmethod
    def joining(delimiter: java.lang.CharSequence, /) -> Collector[java.lang.CharSequence, java.lang.Object, java.lang.String]: ...
    @typing.overload
    @staticmethod
    def joining(delimiter: java.lang.CharSequence, prefix: java.lang.CharSequence, suffix: java.lang.CharSequence, /) -> Collector[java.lang.CharSequence, java.lang.Object, java.lang.String]: ...
    _mapping__T = typing.TypeVar('_mapping__T')  # <T>
    _mapping__U = typing.TypeVar('_mapping__U')  # <U>
    _mapping__R = typing.TypeVar('_mapping__R')  # <R>
    @staticmethod
    def mapping(mapper: java.util.function.Function[_mapping__T, _mapping__U], downstream: Collector[_mapping__U, java.lang.Object, _mapping__R], /) -> Collector[_mapping__T, java.lang.Object, _mapping__R]: ...
    _maxBy__T = typing.TypeVar('_maxBy__T')  # <T>
    @staticmethod
    def maxBy(comparator: java.util.Comparator[_maxBy__T], /) -> Collector[_maxBy__T, java.lang.Object, java.util.Optional[_maxBy__T]]: ...
    _minBy__T = typing.TypeVar('_minBy__T')  # <T>
    @staticmethod
    def minBy(comparator: java.util.Comparator[_minBy__T], /) -> Collector[_minBy__T, java.lang.Object, java.util.Optional[_minBy__T]]: ...
    _partitioningBy_0__T = typing.TypeVar('_partitioningBy_0__T')  # <T>
    _partitioningBy_1__T = typing.TypeVar('_partitioningBy_1__T')  # <T>
    _partitioningBy_1__D = typing.TypeVar('_partitioningBy_1__D')  # <D>
    @typing.overload
    @staticmethod
    def partitioningBy(predicate: java.util.function.Predicate[_partitioningBy_0__T], /) -> Collector[_partitioningBy_0__T, java.lang.Object, java.util.Map[java.lang.Boolean, java.util.List[_partitioningBy_0__T]]]: ...
    @typing.overload
    @staticmethod
    def partitioningBy(predicate: java.util.function.Predicate[_partitioningBy_1__T], downstream: Collector[_partitioningBy_1__T, java.lang.Object, _partitioningBy_1__D], /) -> Collector[_partitioningBy_1__T, java.lang.Object, java.util.Map[java.lang.Boolean, _partitioningBy_1__D]]: ...
    _reducing_0__T = typing.TypeVar('_reducing_0__T')  # <T>
    _reducing_1__T = typing.TypeVar('_reducing_1__T')  # <T>
    _reducing_2__T = typing.TypeVar('_reducing_2__T')  # <T>
    _reducing_2__U = typing.TypeVar('_reducing_2__U')  # <U>
    @typing.overload
    @staticmethod
    def reducing(op: java.util.function.BinaryOperator[_reducing_0__T], /) -> Collector[_reducing_0__T, java.lang.Object, java.util.Optional[_reducing_0__T]]: ...
    @typing.overload
    @staticmethod
    def reducing(identity: _reducing_1__T, op: java.util.function.BinaryOperator[_reducing_1__T], /) -> Collector[_reducing_1__T, java.lang.Object, _reducing_1__T]: ...
    @typing.overload
    @staticmethod
    def reducing(identity: _reducing_2__U, mapper: java.util.function.Function[_reducing_2__T, _reducing_2__U], op: java.util.function.BinaryOperator[_reducing_2__U], /) -> Collector[_reducing_2__T, java.lang.Object, _reducing_2__U]: ...
    _summarizingDouble__T = typing.TypeVar('_summarizingDouble__T')  # <T>
    @staticmethod
    def summarizingDouble(mapper: java.util.function.ToDoubleFunction[_summarizingDouble__T], /) -> Collector[_summarizingDouble__T, java.lang.Object, java.util.DoubleSummaryStatistics]: ...
    _summarizingInt__T = typing.TypeVar('_summarizingInt__T')  # <T>
    @staticmethod
    def summarizingInt(mapper: java.util.function.ToIntFunction[_summarizingInt__T], /) -> Collector[_summarizingInt__T, java.lang.Object, java.util.IntSummaryStatistics]: ...
    _summarizingLong__T = typing.TypeVar('_summarizingLong__T')  # <T>
    @staticmethod
    def summarizingLong(mapper: java.util.function.ToLongFunction[_summarizingLong__T], /) -> Collector[_summarizingLong__T, java.lang.Object, java.util.LongSummaryStatistics]: ...
    _summingDouble__T = typing.TypeVar('_summingDouble__T')  # <T>
    @staticmethod
    def summingDouble(mapper: java.util.function.ToDoubleFunction[_summingDouble__T], /) -> Collector[_summingDouble__T, java.lang.Object, java.lang.Double]: ...
    _summingInt__T = typing.TypeVar('_summingInt__T')  # <T>
    @staticmethod
    def summingInt(mapper: java.util.function.ToIntFunction[_summingInt__T], /) -> Collector[_summingInt__T, java.lang.Object, java.lang.Integer]: ...
    _summingLong__T = typing.TypeVar('_summingLong__T')  # <T>
    @staticmethod
    def summingLong(mapper: java.util.function.ToLongFunction[_summingLong__T], /) -> Collector[_summingLong__T, java.lang.Object, java.lang.Long]: ...
    _teeing__T = typing.TypeVar('_teeing__T')  # <T>
    _teeing__R1 = typing.TypeVar('_teeing__R1')  # <R1>
    _teeing__R2 = typing.TypeVar('_teeing__R2')  # <R2>
    _teeing__R = typing.TypeVar('_teeing__R')  # <R>
    @staticmethod
    def teeing(downstream1: Collector[_teeing__T, java.lang.Object, _teeing__R1], downstream2: Collector[_teeing__T, java.lang.Object, _teeing__R2], merger: java.util.function.BiFunction[_teeing__R1, _teeing__R2, _teeing__R], /) -> Collector[_teeing__T, java.lang.Object, _teeing__R]: ...
    _toCollection__C = typing.TypeVar('_toCollection__C')  # <C>
    @staticmethod
    def toCollection(collectionFactory: java.util.function.Supplier[_toCollection__C], /) -> Collector[java.lang.Object, java.lang.Object, _toCollection__C]: ...
    _toConcurrentMap_0__T = typing.TypeVar('_toConcurrentMap_0__T')  # <T>
    _toConcurrentMap_0__K = typing.TypeVar('_toConcurrentMap_0__K')  # <K>
    _toConcurrentMap_0__U = typing.TypeVar('_toConcurrentMap_0__U')  # <U>
    _toConcurrentMap_1__T = typing.TypeVar('_toConcurrentMap_1__T')  # <T>
    _toConcurrentMap_1__K = typing.TypeVar('_toConcurrentMap_1__K')  # <K>
    _toConcurrentMap_1__U = typing.TypeVar('_toConcurrentMap_1__U')  # <U>
    _toConcurrentMap_2__T = typing.TypeVar('_toConcurrentMap_2__T')  # <T>
    _toConcurrentMap_2__U = typing.TypeVar('_toConcurrentMap_2__U')  # <U>
    _toConcurrentMap_2__M = typing.TypeVar('_toConcurrentMap_2__M')  # <M>
    @typing.overload
    @staticmethod
    def toConcurrentMap(keyMapper: java.util.function.Function[_toConcurrentMap_0__T, _toConcurrentMap_0__K], valueMapper: java.util.function.Function[_toConcurrentMap_0__T, _toConcurrentMap_0__U], /) -> Collector[_toConcurrentMap_0__T, java.lang.Object, java.util.concurrent.ConcurrentMap[_toConcurrentMap_0__K, _toConcurrentMap_0__U]]: ...
    @typing.overload
    @staticmethod
    def toConcurrentMap(keyMapper: java.util.function.Function[_toConcurrentMap_1__T, _toConcurrentMap_1__K], valueMapper: java.util.function.Function[_toConcurrentMap_1__T, _toConcurrentMap_1__U], mergeFunction: java.util.function.BinaryOperator[_toConcurrentMap_1__U], /) -> Collector[_toConcurrentMap_1__T, java.lang.Object, java.util.concurrent.ConcurrentMap[_toConcurrentMap_1__K, _toConcurrentMap_1__U]]: ...
    @typing.overload
    @staticmethod
    def toConcurrentMap(keyMapper: java.util.function.Function[_toConcurrentMap_2__T, java.lang.Object], valueMapper: java.util.function.Function[_toConcurrentMap_2__T, _toConcurrentMap_2__U], mergeFunction: java.util.function.BinaryOperator[_toConcurrentMap_2__U], mapFactory: java.util.function.Supplier[_toConcurrentMap_2__M], /) -> Collector[_toConcurrentMap_2__T, java.lang.Object, _toConcurrentMap_2__M]: ...
    _toList__T = typing.TypeVar('_toList__T')  # <T>
    @staticmethod
    def toList() -> Collector[_toList__T, java.lang.Object, java.util.List[_toList__T]]: ...
    _toMap_0__T = typing.TypeVar('_toMap_0__T')  # <T>
    _toMap_0__K = typing.TypeVar('_toMap_0__K')  # <K>
    _toMap_0__U = typing.TypeVar('_toMap_0__U')  # <U>
    _toMap_1__T = typing.TypeVar('_toMap_1__T')  # <T>
    _toMap_1__K = typing.TypeVar('_toMap_1__K')  # <K>
    _toMap_1__U = typing.TypeVar('_toMap_1__U')  # <U>
    _toMap_2__T = typing.TypeVar('_toMap_2__T')  # <T>
    _toMap_2__U = typing.TypeVar('_toMap_2__U')  # <U>
    _toMap_2__M = typing.TypeVar('_toMap_2__M')  # <M>
    @typing.overload
    @staticmethod
    def toMap(keyMapper: java.util.function.Function[_toMap_0__T, _toMap_0__K], valueMapper: java.util.function.Function[_toMap_0__T, _toMap_0__U], /) -> Collector[_toMap_0__T, java.lang.Object, java.util.Map[_toMap_0__K, _toMap_0__U]]: ...
    @typing.overload
    @staticmethod
    def toMap(keyMapper: java.util.function.Function[_toMap_1__T, _toMap_1__K], valueMapper: java.util.function.Function[_toMap_1__T, _toMap_1__U], mergeFunction: java.util.function.BinaryOperator[_toMap_1__U], /) -> Collector[_toMap_1__T, java.lang.Object, java.util.Map[_toMap_1__K, _toMap_1__U]]: ...
    @typing.overload
    @staticmethod
    def toMap(keyMapper: java.util.function.Function[_toMap_2__T, java.lang.Object], valueMapper: java.util.function.Function[_toMap_2__T, _toMap_2__U], mergeFunction: java.util.function.BinaryOperator[_toMap_2__U], mapFactory: java.util.function.Supplier[_toMap_2__M], /) -> Collector[_toMap_2__T, java.lang.Object, _toMap_2__M]: ...
    _toSet__T = typing.TypeVar('_toSet__T')  # <T>
    @staticmethod
    def toSet() -> Collector[_toSet__T, java.lang.Object, java.util.Set[_toSet__T]]: ...
    _toUnmodifiableList__T = typing.TypeVar('_toUnmodifiableList__T')  # <T>
    @staticmethod
    def toUnmodifiableList() -> Collector[_toUnmodifiableList__T, java.lang.Object, java.util.List[_toUnmodifiableList__T]]: ...
    _toUnmodifiableMap_0__T = typing.TypeVar('_toUnmodifiableMap_0__T')  # <T>
    _toUnmodifiableMap_0__K = typing.TypeVar('_toUnmodifiableMap_0__K')  # <K>
    _toUnmodifiableMap_0__U = typing.TypeVar('_toUnmodifiableMap_0__U')  # <U>
    _toUnmodifiableMap_1__T = typing.TypeVar('_toUnmodifiableMap_1__T')  # <T>
    _toUnmodifiableMap_1__K = typing.TypeVar('_toUnmodifiableMap_1__K')  # <K>
    _toUnmodifiableMap_1__U = typing.TypeVar('_toUnmodifiableMap_1__U')  # <U>
    @typing.overload
    @staticmethod
    def toUnmodifiableMap(keyMapper: java.util.function.Function[_toUnmodifiableMap_0__T, _toUnmodifiableMap_0__K], valueMapper: java.util.function.Function[_toUnmodifiableMap_0__T, _toUnmodifiableMap_0__U], /) -> Collector[_toUnmodifiableMap_0__T, java.lang.Object, java.util.Map[_toUnmodifiableMap_0__K, _toUnmodifiableMap_0__U]]: ...
    @typing.overload
    @staticmethod
    def toUnmodifiableMap(keyMapper: java.util.function.Function[_toUnmodifiableMap_1__T, _toUnmodifiableMap_1__K], valueMapper: java.util.function.Function[_toUnmodifiableMap_1__T, _toUnmodifiableMap_1__U], mergeFunction: java.util.function.BinaryOperator[_toUnmodifiableMap_1__U], /) -> Collector[_toUnmodifiableMap_1__T, java.lang.Object, java.util.Map[_toUnmodifiableMap_1__K, _toUnmodifiableMap_1__U]]: ...
    _toUnmodifiableSet__T = typing.TypeVar('_toUnmodifiableSet__T')  # <T>
    @staticmethod
    def toUnmodifiableSet() -> Collector[_toUnmodifiableSet__T, java.lang.Object, java.util.Set[_toUnmodifiableSet__T]]: ...

class DoubleStream(BaseStream[java.lang.Double, DoubleStream]):
    def allMatch(self, arg1: java.util.function.DoublePredicate, /) -> bool: ...
    def anyMatch(self, arg1: java.util.function.DoublePredicate, /) -> bool: ...
    def average(self) -> java.util.OptionalDouble: ...
    def boxed(self) -> Stream[java.lang.Double]: ...
    @staticmethod
    def builder() -> DoubleStream.Builder: ...
    _collect__R = typing.TypeVar('_collect__R')  # <R>
    def collect(self, arg1: java.util.function.Supplier[_collect__R], arg2: java.util.function.ObjDoubleConsumer[_collect__R], arg3: java.util.function.BiConsumer[_collect__R, _collect__R], /) -> _collect__R: ...
    @staticmethod
    def concat(a: DoubleStream, b: DoubleStream, /) -> DoubleStream: ...
    def count(self) -> int: ...
    def distinct(self) -> DoubleStream: ...
    def dropWhile(self, predicate: java.util.function.DoublePredicate, /) -> DoubleStream: ...
    @staticmethod
    def empty() -> DoubleStream: ...
    def filter(self, arg1: java.util.function.DoublePredicate, /) -> DoubleStream: ...
    def findAny(self) -> java.util.OptionalDouble: ...
    def findFirst(self) -> java.util.OptionalDouble: ...
    def flatMap(self, arg1: java.util.function.DoubleFunction[DoubleStream], /) -> DoubleStream: ...
    def forEach(self, arg1: java.util.function.DoubleConsumer, /) -> None: ...
    def forEachOrdered(self, arg1: java.util.function.DoubleConsumer, /) -> None: ...
    @staticmethod
    def generate(s: java.util.function.DoubleSupplier, /) -> DoubleStream: ...
    @typing.overload
    @staticmethod
    def iterate(seed: float | java.jdouble | java.lang.Double, f: java.util.function.DoubleUnaryOperator, /) -> DoubleStream: ...
    @typing.overload
    @staticmethod
    def iterate(seed: float | java.jdouble | java.lang.Double, hasNext: java.util.function.DoublePredicate, next: java.util.function.DoubleUnaryOperator, /) -> DoubleStream: ...
    def iterator(self) -> java.util.PrimitiveIterator.OfDouble: ...
    def limit(self, arg1: int | java.jlong | java.lang.Long, /) -> DoubleStream: ...
    def map(self, arg1: java.util.function.DoubleUnaryOperator, /) -> DoubleStream: ...
    def mapMulti(self, mapper: DoubleStream.DoubleMapMultiConsumer, /) -> DoubleStream: ...
    def mapToInt(self, arg1: java.util.function.DoubleToIntFunction, /) -> IntStream: ...
    def mapToLong(self, arg1: java.util.function.DoubleToLongFunction, /) -> LongStream: ...
    _mapToObj__U = typing.TypeVar('_mapToObj__U')  # <U>
    def mapToObj(self, arg1: java.util.function.DoubleFunction[_mapToObj__U], /) -> Stream[_mapToObj__U]: ...
    def max(self) -> java.util.OptionalDouble: ...
    def min(self) -> java.util.OptionalDouble: ...
    def noneMatch(self, arg1: java.util.function.DoublePredicate, /) -> bool: ...
    @typing.overload
    @staticmethod
    def of(t: float | java.jdouble | java.lang.Double, /) -> DoubleStream: ...
    @typing.overload
    @staticmethod
    def of(*values: java.jdouble) -> DoubleStream: ...
    def parallel(self) -> DoubleStream: ...
    def peek(self, arg1: java.util.function.DoubleConsumer, /) -> DoubleStream: ...
    @typing.overload
    def reduce(self, arg1: java.util.function.DoubleBinaryOperator, /) -> java.util.OptionalDouble: ...
    @typing.overload
    def reduce(self, arg1: float | java.jdouble | java.lang.Double, arg2: java.util.function.DoubleBinaryOperator, /) -> float: ...
    def sequential(self) -> DoubleStream: ...
    def skip(self, arg1: int | java.jlong | java.lang.Long, /) -> DoubleStream: ...
    def sorted(self) -> DoubleStream: ...
    def spliterator(self) -> java.util.Spliterator.OfDouble: ...
    def sum(self) -> float: ...
    def summaryStatistics(self) -> java.util.DoubleSummaryStatistics: ...
    def takeWhile(self, predicate: java.util.function.DoublePredicate, /) -> DoubleStream: ...
    def toArray(self) -> java.chaquopy.JavaArrayJDouble: ...

    class DoubleMapMultiConsumer(java.lang.Object):
        def accept(self, arg1: float | java.jdouble | java.lang.Double, arg2: java.util.function.DoubleConsumer, /) -> None: ...

    class Builder(java.util.function.DoubleConsumer):
        def accept(self, arg1: float | java.jdouble | java.lang.Double, /) -> None: ...
        def add(self, t: float | java.jdouble | java.lang.Double, /) -> DoubleStream.Builder: ...
        def build(self) -> DoubleStream: ...

class IntStream(BaseStream[java.lang.Integer, IntStream]):
    def allMatch(self, arg1: java.util.function.IntPredicate, /) -> bool: ...
    def anyMatch(self, arg1: java.util.function.IntPredicate, /) -> bool: ...
    def asDoubleStream(self) -> DoubleStream: ...
    def asLongStream(self) -> LongStream: ...
    def average(self) -> java.util.OptionalDouble: ...
    def boxed(self) -> Stream[java.lang.Integer]: ...
    @staticmethod
    def builder() -> IntStream.Builder: ...
    _collect__R = typing.TypeVar('_collect__R')  # <R>
    def collect(self, arg1: java.util.function.Supplier[_collect__R], arg2: java.util.function.ObjIntConsumer[_collect__R], arg3: java.util.function.BiConsumer[_collect__R, _collect__R], /) -> _collect__R: ...
    @staticmethod
    def concat(a: IntStream, b: IntStream, /) -> IntStream: ...
    def count(self) -> int: ...
    def distinct(self) -> IntStream: ...
    def dropWhile(self, predicate: java.util.function.IntPredicate, /) -> IntStream: ...
    @staticmethod
    def empty() -> IntStream: ...
    def filter(self, arg1: java.util.function.IntPredicate, /) -> IntStream: ...
    def findAny(self) -> java.util.OptionalInt: ...
    def findFirst(self) -> java.util.OptionalInt: ...
    def flatMap(self, arg1: java.util.function.IntFunction[IntStream], /) -> IntStream: ...
    def forEach(self, arg1: java.util.function.IntConsumer, /) -> None: ...
    def forEachOrdered(self, arg1: java.util.function.IntConsumer, /) -> None: ...
    @staticmethod
    def generate(s: java.util.function.IntSupplier, /) -> IntStream: ...
    @typing.overload
    @staticmethod
    def iterate(seed: int | java.jint | java.lang.Integer, f: java.util.function.IntUnaryOperator, /) -> IntStream: ...
    @typing.overload
    @staticmethod
    def iterate(seed: int | java.jint | java.lang.Integer, hasNext: java.util.function.IntPredicate, next: java.util.function.IntUnaryOperator, /) -> IntStream: ...
    def iterator(self) -> java.util.PrimitiveIterator.OfInt: ...
    def limit(self, arg1: int | java.jlong | java.lang.Long, /) -> IntStream: ...
    def map(self, arg1: java.util.function.IntUnaryOperator, /) -> IntStream: ...
    def mapMulti(self, mapper: IntStream.IntMapMultiConsumer, /) -> IntStream: ...
    def mapToDouble(self, arg1: java.util.function.IntToDoubleFunction, /) -> DoubleStream: ...
    def mapToLong(self, arg1: java.util.function.IntToLongFunction, /) -> LongStream: ...
    _mapToObj__U = typing.TypeVar('_mapToObj__U')  # <U>
    def mapToObj(self, arg1: java.util.function.IntFunction[_mapToObj__U], /) -> Stream[_mapToObj__U]: ...
    def max(self) -> java.util.OptionalInt: ...
    def min(self) -> java.util.OptionalInt: ...
    def noneMatch(self, arg1: java.util.function.IntPredicate, /) -> bool: ...
    @typing.overload
    @staticmethod
    def of(t: int | java.jint | java.lang.Integer, /) -> IntStream: ...
    @typing.overload
    @staticmethod
    def of(*values: java.jint) -> IntStream: ...
    def parallel(self) -> IntStream: ...
    def peek(self, arg1: java.util.function.IntConsumer, /) -> IntStream: ...
    @staticmethod
    def range(startInclusive: int | java.jint | java.lang.Integer, endExclusive: int | java.jint | java.lang.Integer, /) -> IntStream: ...
    @staticmethod
    def rangeClosed(startInclusive: int | java.jint | java.lang.Integer, endInclusive: int | java.jint | java.lang.Integer, /) -> IntStream: ...
    @typing.overload
    def reduce(self, arg1: java.util.function.IntBinaryOperator, /) -> java.util.OptionalInt: ...
    @typing.overload
    def reduce(self, arg1: int | java.jint | java.lang.Integer, arg2: java.util.function.IntBinaryOperator, /) -> int: ...
    def sequential(self) -> IntStream: ...
    def skip(self, arg1: int | java.jlong | java.lang.Long, /) -> IntStream: ...
    def sorted(self) -> IntStream: ...
    def spliterator(self) -> java.util.Spliterator.OfInt: ...
    def sum(self) -> int: ...
    def summaryStatistics(self) -> java.util.IntSummaryStatistics: ...
    def takeWhile(self, predicate: java.util.function.IntPredicate, /) -> IntStream: ...
    def toArray(self) -> java.chaquopy.JavaArrayJInt: ...

    class IntMapMultiConsumer(java.lang.Object):
        def accept(self, arg1: int | java.jint | java.lang.Integer, arg2: java.util.function.IntConsumer, /) -> None: ...

    class Builder(java.util.function.IntConsumer):
        def accept(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        def add(self, t: int | java.jint | java.lang.Integer, /) -> IntStream.Builder: ...
        def build(self) -> IntStream: ...

class LongStream(BaseStream[java.lang.Long, LongStream]):
    def allMatch(self, arg1: java.util.function.LongPredicate, /) -> bool: ...
    def anyMatch(self, arg1: java.util.function.LongPredicate, /) -> bool: ...
    def asDoubleStream(self) -> DoubleStream: ...
    def average(self) -> java.util.OptionalDouble: ...
    def boxed(self) -> Stream[java.lang.Long]: ...
    @staticmethod
    def builder() -> LongStream.Builder: ...
    _collect__R = typing.TypeVar('_collect__R')  # <R>
    def collect(self, arg1: java.util.function.Supplier[_collect__R], arg2: java.util.function.ObjLongConsumer[_collect__R], arg3: java.util.function.BiConsumer[_collect__R, _collect__R], /) -> _collect__R: ...
    @staticmethod
    def concat(a: LongStream, b: LongStream, /) -> LongStream: ...
    def count(self) -> int: ...
    def distinct(self) -> LongStream: ...
    def dropWhile(self, predicate: java.util.function.LongPredicate, /) -> LongStream: ...
    @staticmethod
    def empty() -> LongStream: ...
    def filter(self, arg1: java.util.function.LongPredicate, /) -> LongStream: ...
    def findAny(self) -> java.util.OptionalLong: ...
    def findFirst(self) -> java.util.OptionalLong: ...
    def flatMap(self, arg1: java.util.function.LongFunction[LongStream], /) -> LongStream: ...
    def forEach(self, arg1: java.util.function.LongConsumer, /) -> None: ...
    def forEachOrdered(self, arg1: java.util.function.LongConsumer, /) -> None: ...
    @staticmethod
    def generate(s: java.util.function.LongSupplier, /) -> LongStream: ...
    @typing.overload
    @staticmethod
    def iterate(seed: int | java.jlong | java.lang.Long, f: java.util.function.LongUnaryOperator, /) -> LongStream: ...
    @typing.overload
    @staticmethod
    def iterate(seed: int | java.jlong | java.lang.Long, hasNext: java.util.function.LongPredicate, next: java.util.function.LongUnaryOperator, /) -> LongStream: ...
    def iterator(self) -> java.util.PrimitiveIterator.OfLong: ...
    def limit(self, arg1: int | java.jlong | java.lang.Long, /) -> LongStream: ...
    def map(self, arg1: java.util.function.LongUnaryOperator, /) -> LongStream: ...
    def mapMulti(self, mapper: LongStream.LongMapMultiConsumer, /) -> LongStream: ...
    def mapToDouble(self, arg1: java.util.function.LongToDoubleFunction, /) -> DoubleStream: ...
    def mapToInt(self, arg1: java.util.function.LongToIntFunction, /) -> IntStream: ...
    _mapToObj__U = typing.TypeVar('_mapToObj__U')  # <U>
    def mapToObj(self, arg1: java.util.function.LongFunction[_mapToObj__U], /) -> Stream[_mapToObj__U]: ...
    def max(self) -> java.util.OptionalLong: ...
    def min(self) -> java.util.OptionalLong: ...
    def noneMatch(self, arg1: java.util.function.LongPredicate, /) -> bool: ...
    @typing.overload
    @staticmethod
    def of(t: int | java.jlong | java.lang.Long, /) -> LongStream: ...
    @typing.overload
    @staticmethod
    def of(*values: java.jlong) -> LongStream: ...
    def parallel(self) -> LongStream: ...
    def peek(self, arg1: java.util.function.LongConsumer, /) -> LongStream: ...
    @staticmethod
    def range(startInclusive: int | java.jlong | java.lang.Long, endExclusive: int | java.jlong | java.lang.Long, /) -> LongStream: ...
    @staticmethod
    def rangeClosed(startInclusive: int | java.jlong | java.lang.Long, endInclusive: int | java.jlong | java.lang.Long, /) -> LongStream: ...
    @typing.overload
    def reduce(self, arg1: java.util.function.LongBinaryOperator, /) -> java.util.OptionalLong: ...
    @typing.overload
    def reduce(self, arg1: int | java.jlong | java.lang.Long, arg2: java.util.function.LongBinaryOperator, /) -> int: ...
    def sequential(self) -> LongStream: ...
    def skip(self, arg1: int | java.jlong | java.lang.Long, /) -> LongStream: ...
    def sorted(self) -> LongStream: ...
    def spliterator(self) -> java.util.Spliterator.OfLong: ...
    def sum(self) -> int: ...
    def summaryStatistics(self) -> java.util.LongSummaryStatistics: ...
    def takeWhile(self, predicate: java.util.function.LongPredicate, /) -> LongStream: ...
    def toArray(self) -> java.chaquopy.JavaArrayJLong: ...

    class LongMapMultiConsumer(java.lang.Object):
        def accept(self, arg1: int | java.jlong | java.lang.Long, arg2: java.util.function.LongConsumer, /) -> None: ...

    class Builder(java.util.function.LongConsumer):
        def accept(self, arg1: int | java.jlong | java.lang.Long, /) -> None: ...
        def add(self, t: int | java.jlong | java.lang.Long, /) -> LongStream.Builder: ...
        def build(self) -> LongStream: ...

_Stream__T = typing.TypeVar('_Stream__T')  # <T>

_Stream__Builder__T = typing.TypeVar('_Stream__Builder__T')  # <T>
class Stream(BaseStream[_Stream__T, Stream[_Stream__T]], typing.Generic[_Stream__T]):
    def allMatch(self, arg1: java.util.function.Predicate[_Stream__T], /) -> bool: ...
    def anyMatch(self, arg1: java.util.function.Predicate[_Stream__T], /) -> bool: ...
    @staticmethod
    def builder() -> Stream.Builder[java.lang.Object]: ...
    _collect_0__R = typing.TypeVar('_collect_0__R')  # <R>
    _collect_1__R = typing.TypeVar('_collect_1__R')  # <R>
    @typing.overload
    def collect(self, arg1: Collector[_Stream__T, java.lang.Object, _collect_0__R], /) -> _collect_0__R: ...
    @typing.overload
    def collect(self, arg1: java.util.function.Supplier[_collect_1__R], arg2: java.util.function.BiConsumer[_collect_1__R, _Stream__T], arg3: java.util.function.BiConsumer[_collect_1__R, _collect_1__R], /) -> _collect_1__R: ...
    _concat__T = typing.TypeVar('_concat__T')  # <T>
    @staticmethod
    def concat(a: Stream[_concat__T], b: Stream[_concat__T], /) -> Stream[_concat__T]: ...
    def count(self) -> int: ...
    def distinct(self) -> Stream[_Stream__T]: ...
    def dropWhile(self, predicate: java.util.function.Predicate[_Stream__T], /) -> Stream[_Stream__T]: ...
    @staticmethod
    def empty() -> Stream[java.lang.Object]: ...
    def filter(self, arg1: java.util.function.Predicate[_Stream__T], /) -> Stream[_Stream__T]: ...
    def findAny(self) -> java.util.Optional[_Stream__T]: ...
    def findFirst(self) -> java.util.Optional[_Stream__T]: ...
    _flatMap__R = typing.TypeVar('_flatMap__R')  # <R>
    def flatMap(self, arg1: java.util.function.Function[_Stream__T, Stream[_flatMap__R]], /) -> Stream[_flatMap__R]: ...
    def flatMapToDouble(self, arg1: java.util.function.Function[_Stream__T, DoubleStream], /) -> DoubleStream: ...
    def flatMapToInt(self, arg1: java.util.function.Function[_Stream__T, IntStream], /) -> IntStream: ...
    def flatMapToLong(self, arg1: java.util.function.Function[_Stream__T, LongStream], /) -> LongStream: ...
    def forEach(self, arg1: java.util.function.Consumer[_Stream__T], /) -> None: ...
    def forEachOrdered(self, arg1: java.util.function.Consumer[_Stream__T], /) -> None: ...
    _generate__T = typing.TypeVar('_generate__T')  # <T>
    @staticmethod
    def generate(s: java.util.function.Supplier[_generate__T], /) -> Stream[_generate__T]: ...
    _iterate_0__T = typing.TypeVar('_iterate_0__T')  # <T>
    _iterate_1__T = typing.TypeVar('_iterate_1__T')  # <T>
    @typing.overload
    @staticmethod
    def iterate(seed: _iterate_0__T, f: java.util.function.UnaryOperator[_iterate_0__T], /) -> Stream[_iterate_0__T]: ...
    @typing.overload
    @staticmethod
    def iterate(seed: _iterate_1__T, hasNext: java.util.function.Predicate[_iterate_1__T], next: java.util.function.UnaryOperator[_iterate_1__T], /) -> Stream[_iterate_1__T]: ...
    def limit(self, arg1: int | java.jlong | java.lang.Long, /) -> Stream[_Stream__T]: ...
    _map__R = typing.TypeVar('_map__R')  # <R>
    def map(self, arg1: java.util.function.Function[_Stream__T, _map__R], /) -> Stream[_map__R]: ...
    _mapMulti__R = typing.TypeVar('_mapMulti__R')  # <R>
    def mapMulti(self, mapper: java.util.function.BiConsumer[_Stream__T, java.util.function.Consumer[_mapMulti__R]], /) -> Stream[_mapMulti__R]: ...
    def mapMultiToDouble(self, mapper: java.util.function.BiConsumer[_Stream__T, java.util.function.DoubleConsumer], /) -> DoubleStream: ...
    def mapMultiToInt(self, mapper: java.util.function.BiConsumer[_Stream__T, java.util.function.IntConsumer], /) -> IntStream: ...
    def mapMultiToLong(self, mapper: java.util.function.BiConsumer[_Stream__T, java.util.function.LongConsumer], /) -> LongStream: ...
    def mapToDouble(self, arg1: java.util.function.ToDoubleFunction[_Stream__T], /) -> DoubleStream: ...
    def mapToInt(self, arg1: java.util.function.ToIntFunction[_Stream__T], /) -> IntStream: ...
    def mapToLong(self, arg1: java.util.function.ToLongFunction[_Stream__T], /) -> LongStream: ...
    def max(self, arg1: java.util.Comparator[_Stream__T], /) -> java.util.Optional[_Stream__T]: ...
    def min(self, arg1: java.util.Comparator[_Stream__T], /) -> java.util.Optional[_Stream__T]: ...
    def noneMatch(self, arg1: java.util.function.Predicate[_Stream__T], /) -> bool: ...
    _of_0__T = typing.TypeVar('_of_0__T')  # <T>
    _of_1__T = typing.TypeVar('_of_1__T')  # <T>
    @typing.overload
    @staticmethod
    def of(t: _of_0__T, /) -> Stream[_of_0__T]: ...
    @typing.overload
    @staticmethod
    def of(*values: _of_1__T) -> Stream[_of_1__T]: ...
    _ofNullable__T = typing.TypeVar('_ofNullable__T')  # <T>
    @staticmethod
    def ofNullable(t: _ofNullable__T, /) -> Stream[_ofNullable__T]: ...
    def peek(self, arg1: java.util.function.Consumer[_Stream__T], /) -> Stream[_Stream__T]: ...
    _reduce_2__U = typing.TypeVar('_reduce_2__U')  # <U>
    @typing.overload
    def reduce(self, arg1: java.util.function.BinaryOperator[_Stream__T], /) -> java.util.Optional[_Stream__T]: ...
    @typing.overload
    def reduce(self, arg1: _Stream__T, arg2: java.util.function.BinaryOperator[_Stream__T], /) -> _Stream__T: ...
    @typing.overload
    def reduce(self, arg1: _reduce_2__U, arg2: java.util.function.BiFunction[_reduce_2__U, _Stream__T, _reduce_2__U], arg3: java.util.function.BinaryOperator[_reduce_2__U], /) -> _reduce_2__U: ...
    def skip(self, arg1: int | java.jlong | java.lang.Long, /) -> Stream[_Stream__T]: ...
    @typing.overload
    def sorted(self) -> Stream[_Stream__T]: ...
    @typing.overload
    def sorted(self, arg1: java.util.Comparator[_Stream__T], /) -> Stream[_Stream__T]: ...
    def takeWhile(self, predicate: java.util.function.Predicate[_Stream__T], /) -> Stream[_Stream__T]: ...
    _toArray_1__A = typing.TypeVar('_toArray_1__A')  # <A>
    @typing.overload
    def toArray(self) -> java.chaquopy.JavaArray[java.lang.Object]: ...
    @typing.overload
    def toArray(self, arg1: java.util.function.IntFunction[java.chaquopy.JavaArray[_toArray_1__A]], /) -> java.chaquopy.JavaArray[_toArray_1__A]: ...
    def toList(self) -> java.util.List[_Stream__T]: ...
    class Builder(java.util.function.Consumer[_Stream__Builder__T], typing.Generic[_Stream__Builder__T]):
        def accept(self, arg1: _Stream__Builder__T, /) -> None: ...
        def add(self, t: _Stream__Builder__T, /) -> Stream.Builder[_Stream__Builder__T]: ...
        def build(self) -> Stream[_Stream__Builder__T]: ...

class StreamSupport(java.lang.Object):
    @typing.overload
    @staticmethod
    def doubleStream(spliterator: java.util.Spliterator.OfDouble, parallel: bool | java.jboolean | java.lang.Boolean, /) -> DoubleStream: ...
    @typing.overload
    @staticmethod
    def doubleStream(supplier: java.util.function.Supplier[java.util.Spliterator.OfDouble], characteristics: int | java.jint | java.lang.Integer, parallel: bool | java.jboolean | java.lang.Boolean, /) -> DoubleStream: ...
    @typing.overload
    @staticmethod
    def intStream(spliterator: java.util.Spliterator.OfInt, parallel: bool | java.jboolean | java.lang.Boolean, /) -> IntStream: ...
    @typing.overload
    @staticmethod
    def intStream(supplier: java.util.function.Supplier[java.util.Spliterator.OfInt], characteristics: int | java.jint | java.lang.Integer, parallel: bool | java.jboolean | java.lang.Boolean, /) -> IntStream: ...
    @typing.overload
    @staticmethod
    def longStream(spliterator: java.util.Spliterator.OfLong, parallel: bool | java.jboolean | java.lang.Boolean, /) -> LongStream: ...
    @typing.overload
    @staticmethod
    def longStream(supplier: java.util.function.Supplier[java.util.Spliterator.OfLong], characteristics: int | java.jint | java.lang.Integer, parallel: bool | java.jboolean | java.lang.Boolean, /) -> LongStream: ...
    _stream_0__T = typing.TypeVar('_stream_0__T')  # <T>
    _stream_1__T = typing.TypeVar('_stream_1__T')  # <T>
    @typing.overload
    @staticmethod
    def stream(spliterator: java.util.Spliterator[_stream_0__T], parallel: bool | java.jboolean | java.lang.Boolean, /) -> Stream[_stream_0__T]: ...
    @typing.overload
    @staticmethod
    def stream(supplier: java.util.function.Supplier[java.util.Spliterator[_stream_1__T]], characteristics: int | java.jint | java.lang.Integer, parallel: bool | java.jboolean | java.lang.Boolean, /) -> Stream[_stream_1__T]: ...



import typing

import java.lang
import java.lang.invoke

class ObjectMethods(java.lang.Object):
    @staticmethod
    def bootstrap(lookup: java.lang.invoke.MethodHandles.Lookup, methodName: str | java.lang.String, type: java.lang.invoke.TypeDescriptor, recordClass: typing.Type[java.lang.Object], names: str | java.lang.String, /, *getters: java.lang.invoke.MethodHandle) -> java.lang.Object: ...

class SwitchBootstraps(java.lang.Object):
    @staticmethod
    def enumSwitch(lookup: java.lang.invoke.MethodHandles.Lookup, invocationName: str | java.lang.String, invocationType: java.lang.invoke.MethodType, /, *labels: java.lang.Object) -> java.lang.invoke.CallSite: ...
    @staticmethod
    def typeSwitch(lookup: java.lang.invoke.MethodHandles.Lookup, invocationName: str | java.lang.String, invocationType: java.lang.invoke.MethodType, /, *labels: java.lang.Object) -> java.lang.invoke.CallSite: ...



import typing

import android.graphics
import android.graphics.pdf.content
import android.os
import java
import java.lang
import java.util

class PageSelection(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PageSelection]] = ...
    def __init__(self, page: int | java.jint | java.lang.Integer, start: SelectionBoundary, stop: SelectionBoundary, selectedContents: java.util.List[android.graphics.pdf.content.PdfPageTextContent], /) -> None: ...
    def describeContents(self) -> int: ...
    def getPage(self) -> int: ...
    def getSelectedTextContents(self) -> java.util.List[android.graphics.pdf.content.PdfPageTextContent]: ...
    def getStart(self) -> SelectionBoundary: ...
    def getStop(self) -> SelectionBoundary: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SelectionBoundary(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SelectionBoundary]] = ...
    @typing.overload
    def __init__(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, point: android.graphics.Point, /) -> None: ...
    def describeContents(self) -> int: ...
    def getIndex(self) -> int: ...
    def getIsRtl(self) -> bool: ...
    def getPoint(self) -> android.graphics.Point | None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.util.function

class AtomicBoolean(java.io.Serializable):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, initialValue: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def compareAndExchange(self, expectedValue: bool | java.jboolean | java.lang.Boolean, newValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def compareAndExchangeAcquire(self, expectedValue: bool | java.jboolean | java.lang.Boolean, newValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def compareAndExchangeRelease(self, expectedValue: bool | java.jboolean | java.lang.Boolean, newValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def compareAndSet(self, expectedValue: bool | java.jboolean | java.lang.Boolean, newValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def get(self) -> bool: ...
    def getAcquire(self) -> bool: ...
    def getAndSet(self, newValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def getOpaque(self) -> bool: ...
    def getPlain(self) -> bool: ...
    def lazySet(self, newValue: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def set(self, newValue: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOpaque(self, newValue: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPlain(self, newValue: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRelease(self, newValue: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def toString(self) -> str: ...
    def weakCompareAndSet(self, expectedValue: bool | java.jboolean | java.lang.Boolean, newValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def weakCompareAndSetAcquire(self, expectedValue: bool | java.jboolean | java.lang.Boolean, newValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def weakCompareAndSetPlain(self, expectedValue: bool | java.jboolean | java.lang.Boolean, newValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def weakCompareAndSetRelease(self, expectedValue: bool | java.jboolean | java.lang.Boolean, newValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def weakCompareAndSetVolatile(self, expectedValue: bool | java.jboolean | java.lang.Boolean, newValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...

class AtomicInteger(java.io.Serializable, java.lang.Number):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, initialValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def accumulateAndGet(self, x: int | java.jint | java.lang.Integer, accumulatorFunction: java.util.function.IntBinaryOperator, /) -> int: ...
    def addAndGet(self, delta: int | java.jint | java.lang.Integer, /) -> int: ...
    def compareAndExchange(self, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def compareAndExchangeAcquire(self, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def compareAndExchangeRelease(self, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def compareAndSet(self, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> bool: ...
    def decrementAndGet(self) -> int: ...
    def doubleValue(self) -> float: ...
    def floatValue(self) -> float: ...
    def get(self) -> int: ...
    def getAcquire(self) -> int: ...
    def getAndAccumulate(self, x: int | java.jint | java.lang.Integer, accumulatorFunction: java.util.function.IntBinaryOperator, /) -> int: ...
    def getAndAdd(self, delta: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAndDecrement(self) -> int: ...
    def getAndIncrement(self) -> int: ...
    def getAndSet(self, newValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAndUpdate(self, updateFunction: java.util.function.IntUnaryOperator, /) -> int: ...
    def getOpaque(self) -> int: ...
    def getPlain(self) -> int: ...
    def incrementAndGet(self) -> int: ...
    def intValue(self) -> int: ...
    def lazySet(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def longValue(self) -> int: ...
    def set(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOpaque(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPlain(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRelease(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...
    def updateAndGet(self, updateFunction: java.util.function.IntUnaryOperator, /) -> int: ...
    def weakCompareAndSet(self, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> bool: ...
    def weakCompareAndSetAcquire(self, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> bool: ...
    def weakCompareAndSetPlain(self, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> bool: ...
    def weakCompareAndSetRelease(self, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> bool: ...
    def weakCompareAndSetVolatile(self, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> bool: ...

class AtomicIntegerArray(java.io.Serializable):
    @typing.overload
    def __init__(self, length: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, array: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def accumulateAndGet(self, i: int | java.jint | java.lang.Integer, x: int | java.jint | java.lang.Integer, accumulatorFunction: java.util.function.IntBinaryOperator, /) -> int: ...
    def addAndGet(self, i: int | java.jint | java.lang.Integer, delta: int | java.jint | java.lang.Integer, /) -> int: ...
    def compareAndExchange(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def compareAndExchangeAcquire(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def compareAndExchangeRelease(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def compareAndSet(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> bool: ...
    def decrementAndGet(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def get(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAcquire(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAndAccumulate(self, i: int | java.jint | java.lang.Integer, x: int | java.jint | java.lang.Integer, accumulatorFunction: java.util.function.IntBinaryOperator, /) -> int: ...
    def getAndAdd(self, i: int | java.jint | java.lang.Integer, delta: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAndDecrement(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAndIncrement(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAndSet(self, i: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAndUpdate(self, i: int | java.jint | java.lang.Integer, updateFunction: java.util.function.IntUnaryOperator, /) -> int: ...
    def getOpaque(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getPlain(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def incrementAndGet(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def lazySet(self, i: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def length(self) -> int: ...
    def set(self, i: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOpaque(self, i: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPlain(self, i: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRelease(self, i: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...
    def updateAndGet(self, i: int | java.jint | java.lang.Integer, updateFunction: java.util.function.IntUnaryOperator, /) -> int: ...
    def weakCompareAndSet(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> bool: ...
    def weakCompareAndSetAcquire(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> bool: ...
    def weakCompareAndSetPlain(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> bool: ...
    def weakCompareAndSetRelease(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> bool: ...
    def weakCompareAndSetVolatile(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jint | java.lang.Integer, newValue: int | java.jint | java.lang.Integer, /) -> bool: ...

_AtomicIntegerFieldUpdater__T = typing.TypeVar('_AtomicIntegerFieldUpdater__T')  # <T>
class AtomicIntegerFieldUpdater(java.lang.Object, typing.Generic[_AtomicIntegerFieldUpdater__T]):
    def __init__(self) -> None: ...
    def accumulateAndGet(self, obj: _AtomicIntegerFieldUpdater__T, x: int | java.jint | java.lang.Integer, accumulatorFunction: java.util.function.IntBinaryOperator, /) -> int: ...
    def addAndGet(self, obj: _AtomicIntegerFieldUpdater__T, delta: int | java.jint | java.lang.Integer, /) -> int: ...
    def compareAndSet(self, arg1: _AtomicIntegerFieldUpdater__T, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...
    def decrementAndGet(self, obj: _AtomicIntegerFieldUpdater__T, /) -> int: ...
    def get(self, arg1: _AtomicIntegerFieldUpdater__T, /) -> int: ...
    def getAndAccumulate(self, obj: _AtomicIntegerFieldUpdater__T, x: int | java.jint | java.lang.Integer, accumulatorFunction: java.util.function.IntBinaryOperator, /) -> int: ...
    def getAndAdd(self, obj: _AtomicIntegerFieldUpdater__T, delta: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAndDecrement(self, obj: _AtomicIntegerFieldUpdater__T, /) -> int: ...
    def getAndIncrement(self, obj: _AtomicIntegerFieldUpdater__T, /) -> int: ...
    def getAndSet(self, obj: _AtomicIntegerFieldUpdater__T, newValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAndUpdate(self, obj: _AtomicIntegerFieldUpdater__T, updateFunction: java.util.function.IntUnaryOperator, /) -> int: ...
    def incrementAndGet(self, obj: _AtomicIntegerFieldUpdater__T, /) -> int: ...
    def lazySet(self, arg1: _AtomicIntegerFieldUpdater__T, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    _newUpdater__U = typing.TypeVar('_newUpdater__U')  # <U>
    @staticmethod
    def newUpdater(tclass: typing.Type[_newUpdater__U], fieldName: str | java.lang.String, /) -> AtomicIntegerFieldUpdater[_newUpdater__U]: ...
    def set(self, arg1: _AtomicIntegerFieldUpdater__T, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def updateAndGet(self, obj: _AtomicIntegerFieldUpdater__T, updateFunction: java.util.function.IntUnaryOperator, /) -> int: ...
    def weakCompareAndSet(self, arg1: _AtomicIntegerFieldUpdater__T, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...

class AtomicLong(java.io.Serializable, java.lang.Number):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, initialValue: int | java.jlong | java.lang.Long, /) -> None: ...
    def accumulateAndGet(self, x: int | java.jlong | java.lang.Long, accumulatorFunction: java.util.function.LongBinaryOperator, /) -> int: ...
    def addAndGet(self, delta: int | java.jlong | java.lang.Long, /) -> int: ...
    def compareAndExchange(self, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> int: ...
    def compareAndExchangeAcquire(self, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> int: ...
    def compareAndExchangeRelease(self, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> int: ...
    def compareAndSet(self, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> bool: ...
    def decrementAndGet(self) -> int: ...
    def doubleValue(self) -> float: ...
    def floatValue(self) -> float: ...
    def get(self) -> int: ...
    def getAcquire(self) -> int: ...
    def getAndAccumulate(self, x: int | java.jlong | java.lang.Long, accumulatorFunction: java.util.function.LongBinaryOperator, /) -> int: ...
    def getAndAdd(self, delta: int | java.jlong | java.lang.Long, /) -> int: ...
    def getAndDecrement(self) -> int: ...
    def getAndIncrement(self) -> int: ...
    def getAndSet(self, newValue: int | java.jlong | java.lang.Long, /) -> int: ...
    def getAndUpdate(self, updateFunction: java.util.function.LongUnaryOperator, /) -> int: ...
    def getOpaque(self) -> int: ...
    def getPlain(self) -> int: ...
    def incrementAndGet(self) -> int: ...
    def intValue(self) -> int: ...
    def lazySet(self, newValue: int | java.jlong | java.lang.Long, /) -> None: ...
    def longValue(self) -> int: ...
    def set(self, newValue: int | java.jlong | java.lang.Long, /) -> None: ...
    def setOpaque(self, newValue: int | java.jlong | java.lang.Long, /) -> None: ...
    def setPlain(self, newValue: int | java.jlong | java.lang.Long, /) -> None: ...
    def setRelease(self, newValue: int | java.jlong | java.lang.Long, /) -> None: ...
    def toString(self) -> str: ...
    def updateAndGet(self, updateFunction: java.util.function.LongUnaryOperator, /) -> int: ...
    def weakCompareAndSet(self, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> bool: ...
    def weakCompareAndSetAcquire(self, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> bool: ...
    def weakCompareAndSetPlain(self, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> bool: ...
    def weakCompareAndSetRelease(self, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> bool: ...
    def weakCompareAndSetVolatile(self, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> bool: ...

class AtomicLongArray(java.io.Serializable):
    @typing.overload
    def __init__(self, length: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, array: java.chaquopy.JavaArrayJLong, /) -> None: ...
    def accumulateAndGet(self, i: int | java.jint | java.lang.Integer, x: int | java.jlong | java.lang.Long, accumulatorFunction: java.util.function.LongBinaryOperator, /) -> int: ...
    def addAndGet(self, i: int | java.jint | java.lang.Integer, delta: int | java.jlong | java.lang.Long, /) -> int: ...
    def compareAndExchange(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> int: ...
    def compareAndExchangeAcquire(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> int: ...
    def compareAndExchangeRelease(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> int: ...
    def compareAndSet(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> bool: ...
    def decrementAndGet(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def get(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAcquire(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAndAccumulate(self, i: int | java.jint | java.lang.Integer, x: int | java.jlong | java.lang.Long, accumulatorFunction: java.util.function.LongBinaryOperator, /) -> int: ...
    def getAndAdd(self, i: int | java.jint | java.lang.Integer, delta: int | java.jlong | java.lang.Long, /) -> int: ...
    def getAndDecrement(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAndIncrement(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAndSet(self, i: int | java.jint | java.lang.Integer, newValue: int | java.jlong | java.lang.Long, /) -> int: ...
    def getAndUpdate(self, i: int | java.jint | java.lang.Integer, updateFunction: java.util.function.LongUnaryOperator, /) -> int: ...
    def getOpaque(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getPlain(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def incrementAndGet(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def lazySet(self, i: int | java.jint | java.lang.Integer, newValue: int | java.jlong | java.lang.Long, /) -> None: ...
    def length(self) -> int: ...
    def set(self, i: int | java.jint | java.lang.Integer, newValue: int | java.jlong | java.lang.Long, /) -> None: ...
    def setOpaque(self, i: int | java.jint | java.lang.Integer, newValue: int | java.jlong | java.lang.Long, /) -> None: ...
    def setPlain(self, i: int | java.jint | java.lang.Integer, newValue: int | java.jlong | java.lang.Long, /) -> None: ...
    def setRelease(self, i: int | java.jint | java.lang.Integer, newValue: int | java.jlong | java.lang.Long, /) -> None: ...
    def toString(self) -> str: ...
    def updateAndGet(self, i: int | java.jint | java.lang.Integer, updateFunction: java.util.function.LongUnaryOperator, /) -> int: ...
    def weakCompareAndSet(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> bool: ...
    def weakCompareAndSetAcquire(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> bool: ...
    def weakCompareAndSetPlain(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> bool: ...
    def weakCompareAndSetRelease(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> bool: ...
    def weakCompareAndSetVolatile(self, i: int | java.jint | java.lang.Integer, expectedValue: int | java.jlong | java.lang.Long, newValue: int | java.jlong | java.lang.Long, /) -> bool: ...

_AtomicLongFieldUpdater__T = typing.TypeVar('_AtomicLongFieldUpdater__T')  # <T>
class AtomicLongFieldUpdater(java.lang.Object, typing.Generic[_AtomicLongFieldUpdater__T]):
    def __init__(self) -> None: ...
    def accumulateAndGet(self, obj: _AtomicLongFieldUpdater__T, x: int | java.jlong | java.lang.Long, accumulatorFunction: java.util.function.LongBinaryOperator, /) -> int: ...
    def addAndGet(self, obj: _AtomicLongFieldUpdater__T, delta: int | java.jlong | java.lang.Long, /) -> int: ...
    def compareAndSet(self, arg1: _AtomicLongFieldUpdater__T, arg2: int | java.jlong | java.lang.Long, arg3: int | java.jlong | java.lang.Long, /) -> bool: ...
    def decrementAndGet(self, obj: _AtomicLongFieldUpdater__T, /) -> int: ...
    def get(self, arg1: _AtomicLongFieldUpdater__T, /) -> int: ...
    def getAndAccumulate(self, obj: _AtomicLongFieldUpdater__T, x: int | java.jlong | java.lang.Long, accumulatorFunction: java.util.function.LongBinaryOperator, /) -> int: ...
    def getAndAdd(self, obj: _AtomicLongFieldUpdater__T, delta: int | java.jlong | java.lang.Long, /) -> int: ...
    def getAndDecrement(self, obj: _AtomicLongFieldUpdater__T, /) -> int: ...
    def getAndIncrement(self, obj: _AtomicLongFieldUpdater__T, /) -> int: ...
    def getAndSet(self, obj: _AtomicLongFieldUpdater__T, newValue: int | java.jlong | java.lang.Long, /) -> int: ...
    def getAndUpdate(self, obj: _AtomicLongFieldUpdater__T, updateFunction: java.util.function.LongUnaryOperator, /) -> int: ...
    def incrementAndGet(self, obj: _AtomicLongFieldUpdater__T, /) -> int: ...
    def lazySet(self, arg1: _AtomicLongFieldUpdater__T, arg2: int | java.jlong | java.lang.Long, /) -> None: ...
    _newUpdater__U = typing.TypeVar('_newUpdater__U')  # <U>
    @staticmethod
    def newUpdater(tclass: typing.Type[_newUpdater__U], fieldName: str | java.lang.String, /) -> AtomicLongFieldUpdater[_newUpdater__U]: ...
    def set(self, arg1: _AtomicLongFieldUpdater__T, arg2: int | java.jlong | java.lang.Long, /) -> None: ...
    def updateAndGet(self, obj: _AtomicLongFieldUpdater__T, updateFunction: java.util.function.LongUnaryOperator, /) -> int: ...
    def weakCompareAndSet(self, arg1: _AtomicLongFieldUpdater__T, arg2: int | java.jlong | java.lang.Long, arg3: int | java.jlong | java.lang.Long, /) -> bool: ...

_AtomicMarkableReference__V = typing.TypeVar('_AtomicMarkableReference__V')  # <V>
class AtomicMarkableReference(java.lang.Object, typing.Generic[_AtomicMarkableReference__V]):
    def __init__(self, initialRef: _AtomicMarkableReference__V, initialMark: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def attemptMark(self, expectedReference: _AtomicMarkableReference__V, newMark: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def compareAndSet(self, expectedReference: _AtomicMarkableReference__V, newReference: _AtomicMarkableReference__V, expectedMark: bool | java.jboolean | java.lang.Boolean, newMark: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def get(self, markHolder: java.chaquopy.JavaArrayJBoolean, /) -> _AtomicMarkableReference__V: ...
    def getReference(self) -> _AtomicMarkableReference__V: ...
    def isMarked(self) -> bool: ...
    def set(self, newReference: _AtomicMarkableReference__V, newMark: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def weakCompareAndSet(self, expectedReference: _AtomicMarkableReference__V, newReference: _AtomicMarkableReference__V, expectedMark: bool | java.jboolean | java.lang.Boolean, newMark: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...

_AtomicReference__V = typing.TypeVar('_AtomicReference__V')  # <V>
class AtomicReference(java.io.Serializable, typing.Generic[_AtomicReference__V]):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, initialValue: _AtomicReference__V, /) -> None: ...
    def accumulateAndGet(self, x: _AtomicReference__V, accumulatorFunction: java.util.function.BinaryOperator[_AtomicReference__V], /) -> _AtomicReference__V: ...
    def compareAndExchange(self, expectedValue: _AtomicReference__V, newValue: _AtomicReference__V, /) -> _AtomicReference__V: ...
    def compareAndExchangeAcquire(self, expectedValue: _AtomicReference__V, newValue: _AtomicReference__V, /) -> _AtomicReference__V: ...
    def compareAndExchangeRelease(self, expectedValue: _AtomicReference__V, newValue: _AtomicReference__V, /) -> _AtomicReference__V: ...
    def compareAndSet(self, expectedValue: _AtomicReference__V, newValue: _AtomicReference__V, /) -> bool: ...
    def get(self) -> _AtomicReference__V: ...
    def getAcquire(self) -> _AtomicReference__V: ...
    def getAndAccumulate(self, x: _AtomicReference__V, accumulatorFunction: java.util.function.BinaryOperator[_AtomicReference__V], /) -> _AtomicReference__V: ...
    def getAndSet(self, newValue: _AtomicReference__V, /) -> _AtomicReference__V: ...
    def getAndUpdate(self, updateFunction: java.util.function.UnaryOperator[_AtomicReference__V], /) -> _AtomicReference__V: ...
    def getOpaque(self) -> _AtomicReference__V: ...
    def getPlain(self) -> _AtomicReference__V: ...
    def lazySet(self, newValue: _AtomicReference__V, /) -> None: ...
    def set(self, newValue: _AtomicReference__V, /) -> None: ...
    def setOpaque(self, newValue: _AtomicReference__V, /) -> None: ...
    def setPlain(self, newValue: _AtomicReference__V, /) -> None: ...
    def setRelease(self, newValue: _AtomicReference__V, /) -> None: ...
    def toString(self) -> str: ...
    def updateAndGet(self, updateFunction: java.util.function.UnaryOperator[_AtomicReference__V], /) -> _AtomicReference__V: ...
    def weakCompareAndSet(self, expectedValue: _AtomicReference__V, newValue: _AtomicReference__V, /) -> bool: ...
    def weakCompareAndSetAcquire(self, expectedValue: _AtomicReference__V, newValue: _AtomicReference__V, /) -> bool: ...
    def weakCompareAndSetPlain(self, expectedValue: _AtomicReference__V, newValue: _AtomicReference__V, /) -> bool: ...
    def weakCompareAndSetRelease(self, expectedValue: _AtomicReference__V, newValue: _AtomicReference__V, /) -> bool: ...
    def weakCompareAndSetVolatile(self, expectedValue: _AtomicReference__V, newValue: _AtomicReference__V, /) -> bool: ...

_AtomicReferenceArray__E = typing.TypeVar('_AtomicReferenceArray__E')  # <E>
class AtomicReferenceArray(java.io.Serializable, typing.Generic[_AtomicReferenceArray__E]):
    @typing.overload
    def __init__(self, length: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, array: java.chaquopy.JavaArray[_AtomicReferenceArray__E], /) -> None: ...
    def accumulateAndGet(self, i: int | java.jint | java.lang.Integer, x: _AtomicReferenceArray__E, accumulatorFunction: java.util.function.BinaryOperator[_AtomicReferenceArray__E], /) -> _AtomicReferenceArray__E: ...
    def compareAndExchange(self, i: int | java.jint | java.lang.Integer, expectedValue: _AtomicReferenceArray__E, newValue: _AtomicReferenceArray__E, /) -> _AtomicReferenceArray__E: ...
    def compareAndExchangeAcquire(self, i: int | java.jint | java.lang.Integer, expectedValue: _AtomicReferenceArray__E, newValue: _AtomicReferenceArray__E, /) -> _AtomicReferenceArray__E: ...
    def compareAndExchangeRelease(self, i: int | java.jint | java.lang.Integer, expectedValue: _AtomicReferenceArray__E, newValue: _AtomicReferenceArray__E, /) -> _AtomicReferenceArray__E: ...
    def compareAndSet(self, i: int | java.jint | java.lang.Integer, expectedValue: _AtomicReferenceArray__E, newValue: _AtomicReferenceArray__E, /) -> bool: ...
    def get(self, i: int | java.jint | java.lang.Integer, /) -> _AtomicReferenceArray__E: ...
    def getAcquire(self, i: int | java.jint | java.lang.Integer, /) -> _AtomicReferenceArray__E: ...
    def getAndAccumulate(self, i: int | java.jint | java.lang.Integer, x: _AtomicReferenceArray__E, accumulatorFunction: java.util.function.BinaryOperator[_AtomicReferenceArray__E], /) -> _AtomicReferenceArray__E: ...
    def getAndSet(self, i: int | java.jint | java.lang.Integer, newValue: _AtomicReferenceArray__E, /) -> _AtomicReferenceArray__E: ...
    def getAndUpdate(self, i: int | java.jint | java.lang.Integer, updateFunction: java.util.function.UnaryOperator[_AtomicReferenceArray__E], /) -> _AtomicReferenceArray__E: ...
    def getOpaque(self, i: int | java.jint | java.lang.Integer, /) -> _AtomicReferenceArray__E: ...
    def getPlain(self, i: int | java.jint | java.lang.Integer, /) -> _AtomicReferenceArray__E: ...
    def lazySet(self, i: int | java.jint | java.lang.Integer, newValue: _AtomicReferenceArray__E, /) -> None: ...
    def length(self) -> int: ...
    def set(self, i: int | java.jint | java.lang.Integer, newValue: _AtomicReferenceArray__E, /) -> None: ...
    def setOpaque(self, i: int | java.jint | java.lang.Integer, newValue: _AtomicReferenceArray__E, /) -> None: ...
    def setPlain(self, i: int | java.jint | java.lang.Integer, newValue: _AtomicReferenceArray__E, /) -> None: ...
    def setRelease(self, i: int | java.jint | java.lang.Integer, newValue: _AtomicReferenceArray__E, /) -> None: ...
    def toString(self) -> str: ...
    def updateAndGet(self, i: int | java.jint | java.lang.Integer, updateFunction: java.util.function.UnaryOperator[_AtomicReferenceArray__E], /) -> _AtomicReferenceArray__E: ...
    def weakCompareAndSet(self, i: int | java.jint | java.lang.Integer, expectedValue: _AtomicReferenceArray__E, newValue: _AtomicReferenceArray__E, /) -> bool: ...
    def weakCompareAndSetAcquire(self, i: int | java.jint | java.lang.Integer, expectedValue: _AtomicReferenceArray__E, newValue: _AtomicReferenceArray__E, /) -> bool: ...
    def weakCompareAndSetPlain(self, i: int | java.jint | java.lang.Integer, expectedValue: _AtomicReferenceArray__E, newValue: _AtomicReferenceArray__E, /) -> bool: ...
    def weakCompareAndSetRelease(self, i: int | java.jint | java.lang.Integer, expectedValue: _AtomicReferenceArray__E, newValue: _AtomicReferenceArray__E, /) -> bool: ...
    def weakCompareAndSetVolatile(self, i: int | java.jint | java.lang.Integer, expectedValue: _AtomicReferenceArray__E, newValue: _AtomicReferenceArray__E, /) -> bool: ...

_AtomicReferenceFieldUpdater__T = typing.TypeVar('_AtomicReferenceFieldUpdater__T')  # <T>
_AtomicReferenceFieldUpdater__V = typing.TypeVar('_AtomicReferenceFieldUpdater__V')  # <V>
class AtomicReferenceFieldUpdater(java.lang.Object, typing.Generic[_AtomicReferenceFieldUpdater__T, _AtomicReferenceFieldUpdater__V]):
    def __init__(self) -> None: ...
    def accumulateAndGet(self, obj: _AtomicReferenceFieldUpdater__T, x: _AtomicReferenceFieldUpdater__V, accumulatorFunction: java.util.function.BinaryOperator[_AtomicReferenceFieldUpdater__V], /) -> _AtomicReferenceFieldUpdater__V: ...
    def compareAndSet(self, arg1: _AtomicReferenceFieldUpdater__T, arg2: _AtomicReferenceFieldUpdater__V, arg3: _AtomicReferenceFieldUpdater__V, /) -> bool: ...
    def get(self, arg1: _AtomicReferenceFieldUpdater__T, /) -> _AtomicReferenceFieldUpdater__V: ...
    def getAndAccumulate(self, obj: _AtomicReferenceFieldUpdater__T, x: _AtomicReferenceFieldUpdater__V, accumulatorFunction: java.util.function.BinaryOperator[_AtomicReferenceFieldUpdater__V], /) -> _AtomicReferenceFieldUpdater__V: ...
    def getAndSet(self, obj: _AtomicReferenceFieldUpdater__T, newValue: _AtomicReferenceFieldUpdater__V, /) -> _AtomicReferenceFieldUpdater__V: ...
    def getAndUpdate(self, obj: _AtomicReferenceFieldUpdater__T, updateFunction: java.util.function.UnaryOperator[_AtomicReferenceFieldUpdater__V], /) -> _AtomicReferenceFieldUpdater__V: ...
    def lazySet(self, arg1: _AtomicReferenceFieldUpdater__T, arg2: _AtomicReferenceFieldUpdater__V, /) -> None: ...
    _newUpdater__U = typing.TypeVar('_newUpdater__U')  # <U>
    _newUpdater__W = typing.TypeVar('_newUpdater__W')  # <W>
    @staticmethod
    def newUpdater(tclass: typing.Type[_newUpdater__U], vclass: typing.Type[_newUpdater__W], fieldName: str | java.lang.String, /) -> AtomicReferenceFieldUpdater[_newUpdater__U, _newUpdater__W]: ...
    def set(self, arg1: _AtomicReferenceFieldUpdater__T, arg2: _AtomicReferenceFieldUpdater__V, /) -> None: ...
    def updateAndGet(self, obj: _AtomicReferenceFieldUpdater__T, updateFunction: java.util.function.UnaryOperator[_AtomicReferenceFieldUpdater__V], /) -> _AtomicReferenceFieldUpdater__V: ...
    def weakCompareAndSet(self, arg1: _AtomicReferenceFieldUpdater__T, arg2: _AtomicReferenceFieldUpdater__V, arg3: _AtomicReferenceFieldUpdater__V, /) -> bool: ...

_AtomicStampedReference__V = typing.TypeVar('_AtomicStampedReference__V')  # <V>
class AtomicStampedReference(java.lang.Object, typing.Generic[_AtomicStampedReference__V]):
    def __init__(self, initialRef: _AtomicStampedReference__V, initialStamp: int | java.jint | java.lang.Integer, /) -> None: ...
    def attemptStamp(self, expectedReference: _AtomicStampedReference__V, newStamp: int | java.jint | java.lang.Integer, /) -> bool: ...
    def compareAndSet(self, expectedReference: _AtomicStampedReference__V, newReference: _AtomicStampedReference__V, expectedStamp: int | java.jint | java.lang.Integer, newStamp: int | java.jint | java.lang.Integer, /) -> bool: ...
    def get(self, stampHolder: java.chaquopy.JavaArrayJInt, /) -> _AtomicStampedReference__V: ...
    def getReference(self) -> _AtomicStampedReference__V: ...
    def getStamp(self) -> int: ...
    def set(self, newReference: _AtomicStampedReference__V, newStamp: int | java.jint | java.lang.Integer, /) -> None: ...
    def weakCompareAndSet(self, expectedReference: _AtomicStampedReference__V, newReference: _AtomicStampedReference__V, expectedStamp: int | java.jint | java.lang.Integer, newStamp: int | java.jint | java.lang.Integer, /) -> bool: ...

class DoubleAccumulator(java.io.Serializable, java.lang.Number):
    def __init__(self, accumulatorFunction: java.util.function.DoubleBinaryOperator, identity: float | java.jdouble | java.lang.Double, /) -> None: ...
    def accumulate(self, x: float | java.jdouble | java.lang.Double, /) -> None: ...
    def doubleValue(self) -> float: ...
    def floatValue(self) -> float: ...
    def get(self) -> float: ...
    def getThenReset(self) -> float: ...
    def intValue(self) -> int: ...
    def longValue(self) -> int: ...
    def reset(self) -> None: ...
    def toString(self) -> str: ...

class DoubleAdder(java.io.Serializable, java.lang.Number):
    def __init__(self) -> None: ...
    def add(self, x: float | java.jdouble | java.lang.Double, /) -> None: ...
    def doubleValue(self) -> float: ...
    def floatValue(self) -> float: ...
    def intValue(self) -> int: ...
    def longValue(self) -> int: ...
    def reset(self) -> None: ...
    def sum(self) -> float: ...
    def sumThenReset(self) -> float: ...
    def toString(self) -> str: ...

class LongAccumulator(java.io.Serializable, java.lang.Number):
    def __init__(self, accumulatorFunction: java.util.function.LongBinaryOperator, identity: int | java.jlong | java.lang.Long, /) -> None: ...
    def accumulate(self, x: int | java.jlong | java.lang.Long, /) -> None: ...
    def doubleValue(self) -> float: ...
    def floatValue(self) -> float: ...
    def get(self) -> int: ...
    def getThenReset(self) -> int: ...
    def intValue(self) -> int: ...
    def longValue(self) -> int: ...
    def reset(self) -> None: ...
    def toString(self) -> str: ...

class LongAdder(java.io.Serializable, java.lang.Number):
    def __init__(self) -> None: ...
    def add(self, x: int | java.jlong | java.lang.Long, /) -> None: ...
    def decrement(self) -> None: ...
    def doubleValue(self) -> float: ...
    def floatValue(self) -> float: ...
    def increment(self) -> None: ...
    def intValue(self) -> int: ...
    def longValue(self) -> int: ...
    def reset(self) -> None: ...
    def sum(self) -> int: ...
    def sumThenReset(self) -> int: ...
    def toString(self) -> str: ...



import typing

import android.content
import java
import java.chaquopy
import java.lang
import java.security
import java.security.cert
import java.time
import java.util

class AccessControlProfile(java.lang.Object):

    class Builder(java.lang.Object):
        def __init__(self, accessControlProfileId: AccessControlProfileId, /) -> None: ...
        def build(self) -> AccessControlProfile: ...
        def setReaderCertificate(self, readerCertificate: java.security.cert.X509Certificate, /) -> AccessControlProfile.Builder: ...
        def setUserAuthenticationRequired(self, userAuthenticationRequired: bool | java.jboolean | java.lang.Boolean, /) -> AccessControlProfile.Builder: ...
        def setUserAuthenticationTimeout(self, userAuthenticationTimeoutMillis: int | java.jlong | java.lang.Long, /) -> AccessControlProfile.Builder: ...

class AccessControlProfileId(java.lang.Object):
    def __init__(self, id: int | java.jint | java.lang.Integer, /) -> None: ...
    def getId(self) -> int: ...

class AlreadyPersonalizedException(IdentityCredentialException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class AuthenticationKeyMetadata(java.lang.Object):
    def getExpirationDate(self) -> java.time.Instant: ...
    def getUsageCount(self) -> int: ...

class CipherSuiteNotSupportedException(IdentityCredentialException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class CredentialDataRequest(java.lang.Object):
    def getDeviceSignedEntriesToRequest(self) -> java.util.Map[java.lang.String, java.util.Collection[java.lang.String]]: ...
    def getIssuerSignedEntriesToRequest(self) -> java.util.Map[java.lang.String, java.util.Collection[java.lang.String]]: ...
    def getReaderSignature(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getRequestMessage(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def isAllowUsingExhaustedKeys(self) -> bool: ...
    def isAllowUsingExpiredKeys(self) -> bool: ...
    def isIncrementUseCount(self) -> bool: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> CredentialDataRequest: ...
        def setAllowUsingExhaustedKeys(self, allowUsingExhaustedKeys: bool | java.jboolean | java.lang.Boolean, /) -> CredentialDataRequest.Builder: ...
        def setAllowUsingExpiredKeys(self, allowUsingExpiredKeys: bool | java.jboolean | java.lang.Boolean, /) -> CredentialDataRequest.Builder: ...
        def setDeviceSignedEntriesToRequest(self, entriesToRequest: java.util.Map[java.lang.String, java.util.Collection[java.lang.String]], /) -> CredentialDataRequest.Builder: ...
        def setIncrementUseCount(self, incrementUseCount: bool | java.jboolean | java.lang.Boolean, /) -> CredentialDataRequest.Builder: ...
        def setIssuerSignedEntriesToRequest(self, entriesToRequest: java.util.Map[java.lang.String, java.util.Collection[java.lang.String]], /) -> CredentialDataRequest.Builder: ...
        def setReaderSignature(self, readerSignature: java.chaquopy.JavaArrayJByte, /) -> CredentialDataRequest.Builder: ...
        def setRequestMessage(self, requestMessage: java.chaquopy.JavaArrayJByte, /) -> CredentialDataRequest.Builder: ...

class CredentialDataResult(java.lang.Object):
    def getDeviceMac(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getDeviceNameSpaces(self) -> java.chaquopy.JavaArrayJByte: ...
    def getDeviceSignature(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getDeviceSignedEntries(self) -> CredentialDataResult.Entries: ...
    def getIssuerSignedEntries(self) -> CredentialDataResult.Entries: ...
    def getStaticAuthenticationData(self) -> java.chaquopy.JavaArrayJByte: ...

    class Entries(java.lang.Object):
        STATUS_NOT_IN_REQUEST_MESSAGE: typing.ClassVar[int] = ...
        STATUS_NOT_REQUESTED: typing.ClassVar[int] = ...
        STATUS_NO_ACCESS_CONTROL_PROFILES: typing.ClassVar[int] = ...
        STATUS_NO_SUCH_ENTRY: typing.ClassVar[int] = ...
        STATUS_OK: typing.ClassVar[int] = ...
        STATUS_READER_AUTHENTICATION_FAILED: typing.ClassVar[int] = ...
        STATUS_USER_AUTHENTICATION_FAILED: typing.ClassVar[int] = ...
        def getEntry(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte: ...
        def getEntryNames(self, arg1: str | java.lang.String, /) -> java.util.Collection[java.lang.String]: ...
        def getNamespaces(self) -> java.util.Collection[java.lang.String]: ...
        def getRetrievedEntryNames(self, arg1: str | java.lang.String, /) -> java.util.Collection[java.lang.String]: ...
        def getStatus(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> int: ...

class DocTypeNotSupportedException(IdentityCredentialException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class EphemeralPublicKeyNotFoundException(IdentityCredentialException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class IdentityCredential(java.lang.Object):
    def createEphemeralKeyPair(self) -> java.security.KeyPair: ...
    def decryptMessageFromReader(self, arg1: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def delete(self, challenge: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def encryptMessageToReader(self, arg1: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def getAuthKeysNeedingCertification(self) -> java.util.Collection[java.security.cert.X509Certificate]: ...
    def getAuthenticationDataUsageCount(self) -> java.chaquopy.JavaArrayJInt: ...
    def getAuthenticationKeyMetadata(self) -> java.util.List[AuthenticationKeyMetadata]: ...
    def getCredentialKeyCertificateChain(self) -> java.util.Collection[java.security.cert.X509Certificate]: ...
    def getEntries(self, arg1: java.chaquopy.JavaArrayJByte, arg2: java.util.Map[java.lang.String, java.util.Collection[java.lang.String]], arg3: java.chaquopy.JavaArrayJByte, arg4: java.chaquopy.JavaArrayJByte, /) -> ResultData: ...
    def proveOwnership(self, challenge: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def setAllowUsingExhaustedKeys(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAllowUsingExpiredKeys(self, allowUsingExpiredKeys: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setAvailableAuthenticationKeys(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setAvailableAuthenticationKeys(self, keyCount: int | java.jint | java.lang.Integer, maxUsesPerKey: int | java.jint | java.lang.Integer, minValidTimeMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def setReaderEphemeralPublicKey(self, arg1: java.security.PublicKey, /) -> None: ...
    @typing.overload
    def storeStaticAuthenticationData(self, arg1: java.security.cert.X509Certificate, arg2: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def storeStaticAuthenticationData(self, authenticationKey: java.security.cert.X509Certificate, expirationDate: java.time.Instant, staticAuthData: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def update(self, personalizationData: PersonalizationData, /) -> java.chaquopy.JavaArrayJByte: ...

class IdentityCredentialException(java.lang.Exception):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class IdentityCredentialStore(java.lang.Object):
    CIPHERSUITE_ECDHE_HKDF_ECDSA_WITH_AES_256_GCM_SHA256: typing.ClassVar[int] = ...
    def createCredential(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> WritableIdentityCredential: ...
    def createPresentationSession(self, cipherSuite: int | java.jint | java.lang.Integer, /) -> PresentationSession: ...
    def deleteCredentialByName(self, arg1: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte | None: ...
    def getCredentialByName(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> IdentityCredential | None: ...
    @staticmethod
    def getDirectAccessInstance(context: android.content.Context, /) -> IdentityCredentialStore | None: ...
    @staticmethod
    def getInstance(context: android.content.Context, /) -> IdentityCredentialStore | None: ...
    def getSupportedDocTypes(self) -> java.chaquopy.JavaArray[java.lang.String]: ...

class InvalidReaderSignatureException(IdentityCredentialException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class InvalidRequestMessageException(IdentityCredentialException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class MessageDecryptionException(IdentityCredentialException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class NoAuthenticationKeyAvailableException(IdentityCredentialException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class PersonalizationData(java.lang.Object):

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addAccessControlProfile(self, profile: AccessControlProfile, /) -> PersonalizationData.Builder: ...
        def build(self) -> PersonalizationData: ...
        def putEntry(self, namespace: str | java.lang.String, name: str | java.lang.String, accessControlProfileIds: java.util.Collection[AccessControlProfileId], value: java.chaquopy.JavaArrayJByte, /) -> PersonalizationData.Builder: ...

class PresentationSession(java.lang.Object):
    def getCredentialData(self, arg1: str | java.lang.String, arg2: CredentialDataRequest, /) -> CredentialDataResult | None: ...
    def getEphemeralKeyPair(self) -> java.security.KeyPair: ...
    def setReaderEphemeralPublicKey(self, arg1: java.security.PublicKey, /) -> None: ...
    def setSessionTranscript(self, arg1: java.chaquopy.JavaArrayJByte, /) -> None: ...

class ResultData(java.lang.Object):
    STATUS_NOT_IN_REQUEST_MESSAGE: typing.ClassVar[int] = ...
    STATUS_NOT_REQUESTED: typing.ClassVar[int] = ...
    STATUS_NO_ACCESS_CONTROL_PROFILES: typing.ClassVar[int] = ...
    STATUS_NO_SUCH_ENTRY: typing.ClassVar[int] = ...
    STATUS_OK: typing.ClassVar[int] = ...
    STATUS_READER_AUTHENTICATION_FAILED: typing.ClassVar[int] = ...
    STATUS_USER_AUTHENTICATION_FAILED: typing.ClassVar[int] = ...
    def getAuthenticatedData(self) -> java.chaquopy.JavaArrayJByte: ...
    def getEntry(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte | None: ...
    def getEntryNames(self, arg1: str | java.lang.String, /) -> java.util.Collection[java.lang.String] | None: ...
    def getMessageAuthenticationCode(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getNamespaces(self) -> java.util.Collection[java.lang.String]: ...
    def getRetrievedEntryNames(self, arg1: str | java.lang.String, /) -> java.util.Collection[java.lang.String] | None: ...
    def getStaticAuthenticationData(self) -> java.chaquopy.JavaArrayJByte: ...
    def getStatus(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> int: ...

class SessionTranscriptMismatchException(IdentityCredentialException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class UnknownAuthenticationKeyException(IdentityCredentialException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class WritableIdentityCredential(java.lang.Object):
    def getCredentialKeyCertificateChain(self, arg1: java.chaquopy.JavaArrayJByte, /) -> java.util.Collection[java.security.cert.X509Certificate]: ...
    def personalize(self, arg1: PersonalizationData, /) -> java.chaquopy.JavaArrayJByte: ...



import android.content
import android.net
import android.os
import java.lang
import java.util.concurrent

class ProtectedSignalsManager(java.lang.Object):
    @staticmethod
    def get(context: android.content.Context, /) -> ProtectedSignalsManager: ...
    def updateSignals(self, updateSignalsRequest: UpdateSignalsRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...

class UpdateSignalsRequest(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getUpdateUri(self) -> android.net.Uri: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

    class Builder(java.lang.Object):
        def __init__(self, updateUri: android.net.Uri, /) -> None: ...
        def build(self) -> UpdateSignalsRequest: ...
        def setUpdateUri(self, updateUri: android.net.Uri, /) -> UpdateSignalsRequest.Builder: ...



import typing

import android.graphics
import android.net
import android.os
import java
import java.lang
import java.util

class PdfPageGotoLinkContent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PdfPageGotoLinkContent]] = ...
    def __init__(self, bounds: java.util.List[android.graphics.RectF], destination: PdfPageGotoLinkContent.Destination, /) -> None: ...
    def describeContents(self) -> int: ...
    def getBounds(self) -> java.util.List[android.graphics.RectF]: ...
    def getDestination(self) -> PdfPageGotoLinkContent.Destination: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Destination(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PdfPageGotoLinkContent.Destination]] = ...
        def __init__(self, pageNumber: int | java.jint | java.lang.Integer, xCoordinate: float | java.jfloat | java.lang.Float, yCoordinate: float | java.jfloat | java.lang.Float, zoom: float | java.jfloat | java.lang.Float, /) -> None: ...
        def describeContents(self) -> int: ...
        def getPageNumber(self) -> int: ...
        def getXCoordinate(self) -> float: ...
        def getYCoordinate(self) -> float: ...
        def getZoom(self) -> float: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PdfPageImageContent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PdfPageImageContent]] = ...
    def __init__(self, altText: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getAltText(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PdfPageLinkContent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PdfPageLinkContent]] = ...
    def __init__(self, bounds: java.util.List[android.graphics.RectF], uri: android.net.Uri, /) -> None: ...
    def describeContents(self) -> int: ...
    def getBounds(self) -> java.util.List[android.graphics.RectF]: ...
    def getUri(self) -> android.net.Uri: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PdfPageTextContent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PdfPageTextContent]] = ...
    @typing.overload
    def __init__(self, text: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, text: str | java.lang.String, bounds: java.util.List[android.graphics.RectF], /) -> None: ...
    def describeContents(self) -> int: ...
    def getBounds(self) -> java.util.List[android.graphics.RectF]: ...
    def getText(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.content
import android.hardware.display
import android.os
import android.view
import java
import java.lang

class MediaProjection(java.lang.Object):
    def createVirtualDisplay(self, name: str | java.lang.String, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, dpi: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, surface: android.view.Surface, callback: android.hardware.display.VirtualDisplay.Callback, handler: android.os.Handler, /) -> android.hardware.display.VirtualDisplay | None: ...
    def registerCallback(self, callback: MediaProjection.Callback, handler: android.os.Handler, /) -> None: ...
    def stop(self) -> None: ...
    def unregisterCallback(self, callback: MediaProjection.Callback, /) -> None: ...

    class Callback(java.lang.Object):
        def __init__(self) -> None: ...
        def onCapturedContentResize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        def onCapturedContentVisibilityChanged(self, isVisible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onStop(self) -> None: ...

class MediaProjectionConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MediaProjectionConfig]] = ...
    @staticmethod
    def createConfigForDefaultDisplay() -> MediaProjectionConfig: ...
    @staticmethod
    def createConfigForUserChoice() -> MediaProjectionConfig: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class MediaProjectionManager(java.lang.Object):
    @typing.overload
    def createScreenCaptureIntent(self) -> android.content.Intent: ...
    @typing.overload
    def createScreenCaptureIntent(self, config: MediaProjectionConfig, /) -> android.content.Intent: ...
    def getMediaProjection(self, resultCode: int | java.jint | java.lang.Integer, resultData: android.content.Intent, /) -> MediaProjection | None: ...



import typing

import android.app
import android.content
import android.os
import java
import java.lang
import java.util
import java.util.concurrent

class GetValueRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GetValueRequest]] = ...
    def describeContents(self) -> int: ...
    def getPreferenceKey(self) -> str: ...
    def getScreenKey(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, screenKey: str | java.lang.String, preferenceKey: str | java.lang.String, /) -> None: ...
        def build(self) -> GetValueRequest: ...

class GetValueResult(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GetValueResult]] = ...
    RESULT_DISALLOW: typing.ClassVar[int] = ...
    RESULT_INTERNAL_ERROR: typing.ClassVar[int] = ...
    RESULT_INVALID_REQUEST: typing.ClassVar[int] = ...
    RESULT_OK: typing.ClassVar[int] = ...
    RESULT_REQUIRE_APP_PERMISSION: typing.ClassVar[int] = ...
    RESULT_UNAVAILABLE: typing.ClassVar[int] = ...
    RESULT_UNSUPPORTED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getMetadata(self) -> SettingsPreferenceMetadata: ...
    def getResultCode(self) -> int: ...
    def getValue(self) -> SettingsPreferenceValue: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, resultCode: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> GetValueResult: ...
        def setMetadata(self, metadata: SettingsPreferenceMetadata, /) -> GetValueResult.Builder: ...
        def setValue(self, value: SettingsPreferenceValue, /) -> GetValueResult.Builder: ...

class MetadataRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MetadataRequest]] = ...
    def describeContents(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> MetadataRequest: ...

class MetadataResult(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MetadataResult]] = ...
    RESULT_INTERNAL_ERROR: typing.ClassVar[int] = ...
    RESULT_OK: typing.ClassVar[int] = ...
    RESULT_UNSUPPORTED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getMetadataList(self) -> java.util.List[SettingsPreferenceMetadata]: ...
    def getResultCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, resultCode: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> MetadataResult: ...
        def setMetadataList(self, metadataList: java.util.List[SettingsPreferenceMetadata], /) -> MetadataResult.Builder: ...

class SetValueRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SetValueRequest]] = ...
    def describeContents(self) -> int: ...
    def getPreferenceKey(self) -> str: ...
    def getPreferenceValue(self) -> SettingsPreferenceValue: ...
    def getScreenKey(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, screenKey: str | java.lang.String, preferenceKey: str | java.lang.String, value: SettingsPreferenceValue, /) -> None: ...
        def build(self) -> SetValueRequest: ...

class SetValueResult(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SetValueResult]] = ...
    RESULT_DISABLED: typing.ClassVar[int] = ...
    RESULT_DISALLOW: typing.ClassVar[int] = ...
    RESULT_INTERNAL_ERROR: typing.ClassVar[int] = ...
    RESULT_INVALID_REQUEST: typing.ClassVar[int] = ...
    RESULT_OK: typing.ClassVar[int] = ...
    RESULT_REQUIRE_APP_PERMISSION: typing.ClassVar[int] = ...
    RESULT_REQUIRE_USER_CONSENT: typing.ClassVar[int] = ...
    RESULT_RESTRICTED: typing.ClassVar[int] = ...
    RESULT_UNAVAILABLE: typing.ClassVar[int] = ...
    RESULT_UNSUPPORTED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getResultCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, resultCode: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> SetValueResult: ...

class SettingsPreferenceMetadata(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SettingsPreferenceMetadata]] = ...
    DEEPLINK_ONLY: typing.ClassVar[int] = ...
    EXPECT_POST_CONFIRMATION: typing.ClassVar[int] = ...
    NO_DIRECT_ACCESS: typing.ClassVar[int] = ...
    NO_SENSITIVITY: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getKey(self) -> str: ...
    def getLaunchIntent(self) -> android.content.Intent: ...
    def getReadPermissions(self) -> java.util.List[java.lang.String]: ...
    def getScreenKey(self) -> str: ...
    def getSummary(self) -> str: ...
    def getTitle(self) -> str: ...
    def getWritePermissions(self) -> java.util.List[java.lang.String]: ...
    def getWriteSensitivity(self) -> int: ...
    def isAvailable(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isRestricted(self) -> bool: ...
    def isWritable(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, screenKey: str | java.lang.String, key: str | java.lang.String, /) -> None: ...
        def build(self) -> SettingsPreferenceMetadata: ...
        def setAvailable(self, available: bool | java.jboolean | java.lang.Boolean, /) -> SettingsPreferenceMetadata.Builder: ...
        def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> SettingsPreferenceMetadata.Builder: ...
        def setExtras(self, extras: android.os.Bundle, /) -> SettingsPreferenceMetadata.Builder: ...
        def setLaunchIntent(self, launchIntent: android.content.Intent, /) -> SettingsPreferenceMetadata.Builder: ...
        def setReadPermissions(self, readPermissions: java.util.List[java.lang.String], /) -> SettingsPreferenceMetadata.Builder: ...
        def setRestricted(self, restricted: bool | java.jboolean | java.lang.Boolean, /) -> SettingsPreferenceMetadata.Builder: ...
        def setSummary(self, summary: str | java.lang.String, /) -> SettingsPreferenceMetadata.Builder: ...
        def setTitle(self, title: str | java.lang.String, /) -> SettingsPreferenceMetadata.Builder: ...
        def setWritable(self, writable: bool | java.jboolean | java.lang.Boolean, /) -> SettingsPreferenceMetadata.Builder: ...
        def setWritePermissions(self, writePermissions: java.util.List[java.lang.String], /) -> SettingsPreferenceMetadata.Builder: ...
        def setWriteSensitivity(self, sensitivity: int | java.jint | java.lang.Integer, /) -> SettingsPreferenceMetadata.Builder: ...

class SettingsPreferenceService(android.app.Service):
    ACTION_PREFERENCE_SERVICE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onGetAllPreferenceMetadata(self, arg1: MetadataRequest, arg2: android.os.OutcomeReceiver[MetadataResult, java.lang.Exception], /) -> None: ...
    def onGetPreferenceValue(self, arg1: GetValueRequest, arg2: android.os.OutcomeReceiver[GetValueResult, java.lang.Exception], /) -> None: ...
    def onSetPreferenceValue(self, arg1: SetValueRequest, arg2: android.os.OutcomeReceiver[SetValueResult, java.lang.Exception], /) -> None: ...

class SettingsPreferenceServiceClient(java.lang.AutoCloseable):
    def __init__(self, context: android.content.Context, packageName: str | java.lang.String, callbackExecutor: java.util.concurrent.Executor, clientReadyCallback: android.os.OutcomeReceiver[SettingsPreferenceServiceClient, java.lang.Exception], /) -> None: ...
    def close(self) -> None: ...
    def getAllPreferenceMetadata(self, request: MetadataRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[MetadataResult, java.lang.Exception], /) -> None: ...
    def getPreferenceValue(self, request: GetValueRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[GetValueResult, java.lang.Exception], /) -> None: ...
    def setPreferenceValue(self, request: SetValueRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[SetValueResult, java.lang.Exception], /) -> None: ...

class SettingsPreferenceValue(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SettingsPreferenceValue]] = ...
    TYPE_BOOLEAN: typing.ClassVar[int] = ...
    TYPE_DOUBLE: typing.ClassVar[int] = ...
    TYPE_INT: typing.ClassVar[int] = ...
    TYPE_LONG: typing.ClassVar[int] = ...
    TYPE_STRING: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getBooleanValue(self) -> bool: ...
    def getDoubleValue(self) -> float: ...
    def getIntValue(self) -> int: ...
    def getLongValue(self) -> int: ...
    def getStringValue(self) -> str: ...
    def getType(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, type: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> SettingsPreferenceValue: ...
        def setBooleanValue(self, booleanValue: bool | java.jboolean | java.lang.Boolean, /) -> SettingsPreferenceValue.Builder: ...
        def setDoubleValue(self, doubleValue: float | java.jdouble | java.lang.Double, /) -> SettingsPreferenceValue.Builder: ...
        def setIntValue(self, intValue: int | java.jint | java.lang.Integer, /) -> SettingsPreferenceValue.Builder: ...
        def setLongValue(self, longValue: int | java.jlong | java.lang.Long, /) -> SettingsPreferenceValue.Builder: ...
        def setStringValue(self, stringValue: str | java.lang.String, /) -> SettingsPreferenceValue.Builder: ...
